@@ -3,10 +3,10 @@
  *  Module    : tin.h
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2005-06-30
+ *  Updated   : 2006-10-01
  *  Notes     : #include files, #defines & struct's
  *
- * Copyright (c) 1997-2006 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1997-2007 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -47,9 +47,7 @@
 #		include	<autoconf.h>	/* FIXME: normally we use 'config.h' */
 #	endif /* !TIN_AUTOCONF_H */
 #else
-#	ifndef HAVE_CONFDEFS_H
-#		include	"oldconfig.h"
-#	endif /* !HAVE_CONFDEFS_H */
+#	error "configure run missing"
 #endif /* HAVE_CONFIG_H */
 
 
@@ -104,62 +102,6 @@ enum icontext { cNone, cGetline, cPromptSLK };
 enum resizer { cNo, cYes, cRedraw };
 enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 
-#ifdef VMS
-#	ifdef __DECC
-#		include <unixio.h>
-#	else
-#		ifndef __VMS_VER	/* assume old types.h */
-			typedef unsigned short mode_t;
-#			undef HAVE_STRFTIME
-#		endif /* !__VMS_VER */
-#		include <stdio.h>
-#	endif /* __DECC */
-#	ifdef SOCKETSHR_TCP
-#		include <socketshr.h>
-#		include <unistd.h>
-#		ifndef SOCKETSHR_HAVE_DUP
-#			define dup
-#		endif /* !SOCKETSHR_HAVE_DUP */
-#		ifndef SOCKETSHR_HAVE_FERROR
-#			define ferror(a) (0)
-#		endif /* !SOCKETSHR_HAVE_FERROR */
-#	endif /* SOCKETSHR_TCP */
-#	include <curses.h>
-#	include <stat.h>
-#	undef HAVE_SELECT
-#	define XHDR_XREF	/* enable crosspost support */
-#	define CASE_PROBLEM
-#	define HAVE_ERRNO_H
-#	define NNTP_ONLY
-#	define NNTP_INEWS
-#	define DONT_HAVE_PIPING
-#	define NO_SHELL_ESCAPE
-#	define USE_CLEARSCREEN
-#	ifndef MM_CHARSET
-#		define MM_CHARSET "ISO-8859-1"
-#	endif /* !MM_CHARSET */
-	/*
-	 * Apparently this means fileops=create if not already there - no idea
-	 * why this should be needed. Standard fopen() implies this in arg 2
-	 */
-	extern char *get_uaf_fullname();
-#	ifdef MULTINET
-#		include "MULTINET_ROOT:[MULTINET.INCLUDE.SYS]TYPES.H"
-#		include "MULTINET_ROOT:[MULTINET.INCLUDE.SYS]TIME.H"
-#	else
-#		include "select.h"
-#		ifdef VAXC
-#			include "vmstimval.h"
-#		endif /* VAXC */
-#		include <types.h>
-#	endif /* !MULTINET */
-#	define FOPEN_OPTS		, "fop=cif"
-#	define JOINPATH		joindir
-#else
-#	define FOPEN_OPTS
-#	define JOINPATH		joinpath
-#endif /* VMS */
-
 #include <stdio.h>
 #ifdef HAVE_ERRNO_H
 #	include	<errno.h>
@@ -204,9 +146,9 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 #	include <sys/times.h>
 #endif /* HAVE_SYS_TIMES_H */
 
-#ifdef HAVE_LIBC_H
+#if defined(HAVE_LIBC_H) && defined(__NeXT__)
 #	include <libc.h>
-#endif /* HAVE_LIBC_H */
+#endif /* HAVE_LIBC_H && __NeXT__ */
 
 #ifdef HAVE_UNISTD_H
 #	include <unistd.h>
@@ -346,29 +288,18 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 /*
  * Directory handling code
  */
-#ifdef HAVE_CONFIG_H
-#	ifdef HAVE_DIRENT_H
-#		include <dirent.h>
-#		define DIR_BUF	struct dirent
-#	else
-#		ifdef HAVE_SYS_DIR_H
-#			include <sys/dir.h>
-#		endif /* HAVE_SYS_DIR_H */
-#		ifdef HAVE_SYS_NDIR_H
-#			include <sys/ndir.h>
-#		endif /* HAVE_SYS_NDIR_H */
-#		define DIR_BUF	struct direct
-#	endif /* HAVE_DIRENT_H */
+#ifdef HAVE_DIRENT_H
+#	include <dirent.h>
+#	define DIR_BUF	struct dirent
 #else
-#	ifdef M_XENIX
+#	ifdef HAVE_SYS_DIR_H
+#		include <sys/dir.h>
+#	endif /* HAVE_SYS_DIR_H */
+#	ifdef HAVE_SYS_NDIR_H
 #		include <sys/ndir.h>
-#		define DIR_BUF	struct direct
-#	endif /* M_XENIX */
-#	ifdef VMS
-#		include "ndir.h"
-#		define DIR_BUF	struct direct
-#	endif /* VMS */
-#endif /* !HAVE_CONFIG_H */
+#	endif /* HAVE_SYS_NDIR_H */
+#	define DIR_BUF	struct direct
+#endif /* HAVE_DIRENT_H */
 
 #ifndef DIR_BUF
 #	include <dirent.h>
@@ -454,39 +385,6 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
  */
 #define VT_ESCAPE_TIMEOUT	1
 
-/*
- * Specify News spool & control directories if not running NNTP_ONLY
- * (on machines who can run configure this is not needed)
- */
-#ifndef HAVE_CONFIG_H
-#	ifndef NNTP_ONLY
-#		ifndef SPOOLDIR
-#			ifdef VMS
-#				define SPOOLDIR	"NEWSSPOOL:[000000]"
-#			else
-#				define SPOOLDIR	"/var/spool/news"
-#			endif /* VMS */
-#		endif /* !SPOOLDIR */
-#		ifndef NEWSLIBDIR
-#			ifdef VMS
-#				define NEWSLIBDIR	"NEWSLIB:[000000]"
-#			else
-#				define NEWSLIBDIR	"/usr/lib/news"
-#			endif /* VMS */
-#		endif /* !NEWSLIBDIR */
-#		ifndef NOVROOTDIR
-#			define NOVROOTDIR	SPOOLDIR
-#		endif /* !NOVROOTDIR */
-#		ifndef INEWSDIR
-#			define INEWSDIR	NEWSLIBDIR
-#		endif /* INEWSDIR */
-#	else
-#		undef	SPOOLDIR
-#		undef	NEWSLIBDIR
-#		undef	NOVROOTDIR
-#	endif /* !NNTP_ONLY */
-#endif /* !HAVE_CONFIG_H */
-
 /*
  * Determine machine configuration for external programs & directories
  */
@@ -534,15 +432,6 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 #	ifdef linux
 #		define DEFAULT_PRINTER	"/usr/bin/lpr"
 #	endif /* linux */
-#	ifdef VMS
-#		define DEFAULT_EDITOR	"EDIT/TPU"
-#		define DEFAULT_MAILBOX	"SYS$LOGIN:"
-#		define DEFAULT_MAILER	"MAIL"
-#		define MAILER_FORMAT	"MAIL /SUBJECT=\"%S\" %F MX%%\"%T\""
-#		define DEFAULT_POSTER	"inews %s."
-#		define DEFAULT_PRINTER	"PRINT/DELETE"
-#		define DEFAULT_UNSHAR	"unshar %s."
-#	endif /* VMS */
 #	ifdef QNX42
 #		ifndef DEFAULT_EDITOR
 #			define DEFAULT_EDITOR	"/bin/vedit"
@@ -643,17 +532,10 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 #define DEFAULT_ACTIVE_NUM	1800
 #define DEFAULT_NEWNEWS_NUM	5
 
-#ifdef VMS
-#	define RCDIR	"TIN"
-#	define INDEX_MAILDIR	"MAILIDX"
-#	define INDEX_NEWSDIR	"INDEX"
-#	define INDEX_SAVEDIR	"SAVE"
-#else
-#	define RCDIR	".tin"
-#	define INDEX_MAILDIR	".mail"
-#	define INDEX_NEWSDIR	".news"
-#	define INDEX_SAVEDIR	".save"
-#endif /* VMS */
+#define RCDIR	".tin"
+#define INDEX_MAILDIR	".mail"
+#define INDEX_NEWSDIR	".news"
+#define INDEX_SAVEDIR	".save"
 
 #define ACTIVE_FILE	"active"
 #define ACTIVE_MAIL_FILE	"active.mail"
@@ -716,6 +598,9 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 /* case sensitive & ^-anchored */
 #define SHAR_REGEX	"\\#(?:!\\s?(?:/usr)?/bin/sh|\\s?(?i)this\\sis\\sa\\sshell\\sarchive)"
 
+/* slrn verbatim marks, case sensitive & ^-anchored */
+#define DEFAULT_VERBATIM_BEGIN_REGEX	"#v+"
+#define DEFAULT_VERBATIM_END_REGEX	"#v-"
 
 /*
  * URL related regexs:
@@ -769,7 +654,7 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 
 #define FILTER_FILE	"filter"
 /* editor offset for filter-file; TODO: doesn't match for german filter-file */
-#define FILTER_FILE_OFFSET	27
+#define FILTER_FILE_OFFSET	26
 #define INPUT_HISTORY_FILE	".inputhistory"
 #ifdef HAVE_MH_MAIL_HANDLING
 #	define MAILGROUPS_FILE	"mailgroups"
@@ -875,11 +760,6 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
  * HEADER_LEN  = max. size of a news/mail header-line
  * NEWSRC_LINE =
  */
-#if defined(VMS)
-#	define PATH_LEN	256
-#	define NAME_LEN	14
-#	define LEN	512
-#endif /* VMS */
 
 #ifdef M_UNIX
 #	ifdef PATH_MAX
@@ -982,6 +862,13 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 #define TINRC_CONFIRM_TO_QUIT	(tinrc.confirm_choice == 3 || tinrc.confirm_choice == 4 || tinrc.confirm_choice == 6 || tinrc.confirm_choice == 7)
 #define TINRC_CONFIRM_SELECT	(tinrc.confirm_choice == 2 || tinrc.confirm_choice == 5 || tinrc.confirm_choice == 6 || tinrc.confirm_choice == 7)
 
+/*
+ * defines for tinrc.goto_next_unread
+ */
+#define NUM_GOTO_NEXT_UNREAD	4
+#define GOTO_NEXT_UNREAD_PGDN	1
+#define GOTO_NEXT_UNREAD_TAB	2
+
 /*
  * MIME Encodings
  */
@@ -1205,6 +1092,8 @@ enum {
 #define SORT_THREADS_BY_NOTHING			0
 #define SORT_THREADS_BY_SCORE_DESCEND	1
 #define SORT_THREADS_BY_SCORE_ASCEND	2
+#define SORT_THREADS_BY_LAST_POSTING_DATE_DESCEND	3
+#define SORT_THREADS_BY_LAST_POSTING_DATE_ASCEND	4
 
 /*
  * Different values of strip_bogus - the ways to handle bogus groups
@@ -1307,15 +1196,11 @@ enum {
 
 #define ESC	27
 
-
 /*
- * return codes for change_config_file ()
+ * filter entrys expire after DEFAULT_FILTER_DAYS
  */
-#define NO_FILTERING		0
-#define FILTERING		1
 #define DEFAULT_FILTER_DAYS		28
 
-
 /*
  * art.thread
  */
@@ -1540,7 +1425,8 @@ struct t_attribute {
 						   3=from descend, 4=from ascend,
 						   5=date descend, 6=date ascend,
 						   7=score descend, 8=score ascend */
-	unsigned sort_threads_type:2;	/* 0=none, 1=score descend, 2=score ascend */
+	unsigned sort_threads_type:3;		/* 0=none, 1=score descend, 2=score ascend,
+						   3=last posting date descend, 4=last posting date ascend */
 	unsigned int post_proc_type:2;		/* 0=none, 1=shar, 2=uudecode */
 	unsigned int x_comment_to:1;		/* insert X-Comment-To: in Followup */
 	unsigned int tex2iso_conv:1;		/* Convert TeX2ISO */
@@ -1851,11 +1737,7 @@ typedef int (*t_compfunc)(t_comptype, t_comptype);
 #define _CDECL
 
 /* Seperator between dir part of path & the filename */
-#ifdef VMS
-#	define DIRSEP	']'
-#else
-#	define DIRSEP	'/'
-#endif /* VMS */
+#define DIRSEP	'/'
 
 /*
  * mouse buttons for use in xterm
@@ -1866,20 +1748,6 @@ typedef int (*t_compfunc)(t_comptype, t_comptype);
 
 #define TIN_EDITOR_FMT_OFF		"%E %F"
 
-#ifdef VMS
-#	define REDIRECT_OUTPUT	""
-#	define REDIRECT_PGP_OUTPUT	""
-#	define ENV_VAR_MAILER		"TIN_MAILER"
-/*#	define ENV_VAR_SHELL		"SHELL"*/
-#	define ENV_VAR_POSTER		"TIN_POST"
-#	define TIN_EDITOR_FMT_ON	"%E %F"
-#	define TMPDIR "SYS$SCRATCH:"
-#	ifdef HAVE_KEY_PREFIX
-#		define KEY_PREFIX	0x9b
-#	endif /* HAVE_KEY_PREFIX */
-extern void joindir (char *result, const char *dir, const char *file);
-#endif /* VMS */
-
 #ifdef M_UNIX
 #	define REDIRECT_OUTPUT		"> /dev/null 2>&1"
 #	define REDIRECT_PGP_OUTPUT		"> /dev/null"
@@ -1918,9 +1786,9 @@ extern void joindir (char *result, const char *dir, const char *file);
 #endif /* !TMPDIR */
 
 #if !defined(S_ISDIR)
-#	if defined(M_UNIX) || defined(VMS)
+#	if defined(M_UNIX)
 #		define S_ISDIR(m)	(((m) & S_IFMT) == S_IFDIR)
-#	endif /* M_UNIX || VMS */
+#	endif /* M_UNIX */
 #endif /* !S_ISDIR */
 
 #if !defined(S_ISREG)
@@ -1964,11 +1832,7 @@ extern void joindir (char *result, const char *dir, const char *file);
 #endif /* !S_ISVTX */
 
 #ifdef DONT_HAVE_PIPING
-#	ifdef VMS
-#		define TIN_PRINTFILE "Sys$Scratch:TIN_PRINT%d.TMP"
-#	else
-#		define TIN_PRINTFILE "tinprint%d.tmp"
-#	endif /* VMS */
+#	define TIN_PRINTFILE "tinprint%d.tmp"
 #endif /* DONT_HAVE_PIPING */
 
 /*
@@ -2114,13 +1978,6 @@ typedef void (*BodyPtr) (char *, FILE *, int);
 	extern void	no_leaks(void);
 #endif /* DOALLOC */
 
-#ifdef __DECC		/* VMS */
-#	ifndef ferror
-#		define ferror(x)		(0)
-#		define EndWin		EndWind
-#	endif /* !ferror */
-#endif /* __DECC */
-
 #ifndef my_tmpfile_only
 /*
  * shortcut if we arn't interrested in the tmpfiles filename/location
@@ -2228,14 +2085,8 @@ extern struct tm *localtime(time_t *);
 #endif /* !EOF */
 
 /* various filenames used by tin */
-#ifndef VMS	/* TODO: is the VMS case needed? */
-#	define TIN_ARTICLE_NAME	".article"
-#	define TIN_CANCEL_NAME	".cancel"
-#	define TIN_LETTER_NAME	".letter"
-#else
-#	define TIN_ARTICLE_NAME	"article."
-#	define TIN_CANCEL_NAME	"cancel."
-#	define TIN_LETTER_NAME	"letter."
-#endif /* !VMS */
+#define TIN_ARTICLE_NAME	".article"
+#define TIN_CANCEL_NAME	".cancel"
+#define TIN_LETTER_NAME	".letter"
 
 #endif /* !TIN_H */
