@@ -3,10 +3,10 @@
  *  Module    : version.h
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2004-10-19
+ *  Updated   : 2006-06-28
  *  Notes     :
  *
- * Copyright (c) 1991-2006 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2007 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -40,21 +40,17 @@
 
 #	define PRODUCT		"tin"
 #	ifndef TIN_AUTOCONF_H
-#		define VERSION		"1.8.0"
+#		define VERSION		"1.9.2"
 #	endif /* !TIN_AUTOCONF_H */
-#	define RELEASEDATE	"20051224"
-#	define RELEASENAME	"Ronay"
+#	define RELEASEDATE	"20070201"
+#	define RELEASENAME	"Dalaruan"
 /* config-file versions - must by dotted triples */
-#	define TINRC_VERSION	"1.3.7"
+#	define TINRC_VERSION	"1.3.8"
 #	define ATTRIBUTES_VERSION	"1.0.4"
 #	define FILTER_VERSION	"1.0.0"
-#	define KEYMAP_VERSION	"1.0.6"
+#	define KEYMAP_VERSION	"1.0.7"
 #	define SERVERCONFIG_VERSION	"1.0.0"
 
-#	ifdef VMS
-#		define OSNAME	"VMS"
-#	endif /* VMS */
-
 #	ifdef M_UNIX
 #		ifdef __BEOS__
 #			define OSNAME	"BeOS"
