@@ -3,10 +3,10 @@
  *  Module    : attrib.c
  *  Author    : I. Lea
  *  Created   : 1993-12-01
- *  Updated   : 2004-03-14
+ *  Updated   : 2006-06-21
  *  Notes     : Group attribute routines
  *
- * Copyright (c) 1993-2005 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1993-2007 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -65,6 +65,7 @@ enum {
 	ATTRIB_DELETE_TMP_FILES,
 	ATTRIB_SHOW_ONLY_UNREAD,
 	ATTRIB_THREAD_ARTS,
+	ATTRIB_THREAD_PERC,
 	ATTRIB_SHOW_AUTHOR,
 	ATTRIB_SHOW_INFO,
 	ATTRIB_SORT_ART_TYPE,
@@ -152,6 +153,7 @@ set_default_attributes(
 	attributes->quick_select_expire = tinrc.default_filter_select_expire;
 	attributes->show_only_unread = tinrc.show_only_unread_arts;
 	attributes->thread_arts = tinrc.thread_articles;
+	attributes->thread_perc = tinrc.thread_perc;
 	attributes->sort_art_type = tinrc.sort_article_type;
 	attributes->sort_threads_type = tinrc.sort_threads_type;
 	attributes->show_info = tinrc.show_info;
@@ -172,10 +174,6 @@ set_default_attributes(
 }
 
 
-/*
- * Load global & local attributes into active[].attribute
- */
-
 #define MATCH_BOOLEAN(pattern, type) \
 	if (match_boolean(line, pattern, &flag)) { \
 		num = (flag != FALSE); \
@@ -203,6 +201,14 @@ set_default_attributes(
 			break; \
 		}
 #endif /* CHARSET_CONVERSION */
+#if !defined(CHARSET_CONVERSION) || !defined(HAVE_ISPELL)
+#	define SKIP_ITEM(pattern) \
+		if (!strncmp(line, pattern, strlen(pattern))) { \
+			found = TRUE; \
+			break; \
+		}
+#endif /* !CHARSET_CONVERSION || !HAVE_ISPELL */
+
 
 /*
  * (re)read global/local attributes file
@@ -287,6 +293,8 @@ read_attributes_file(
 				case 'i':
 #ifdef HAVE_ISPELL
 					MATCH_STRING("ispell=", ATTRIB_ISPELL);
+#else
+					SKIP_ITEM("ispell=");
 #endif /* HAVE_ISPELL */
 					break;
 
@@ -296,7 +304,9 @@ read_attributes_file(
 					MATCH_BOOLEAN("mime_forward=", ATTRIB_MIME_FORWARD);
 					MATCH_STRING("mime_types_to_save=", ATTRIB_MIME_TYPES_TO_SAVE);
 #ifdef CHARSET_CONVERSION
-					MATCH_LIST("mm_network_charset=", ATTRIB_MM_NETWORK_CHARSET,txt_mime_charsets, NUM_MIME_CHARSETS);
+					MATCH_LIST("mm_network_charset=", ATTRIB_MM_NETWORK_CHARSET, txt_mime_charsets, NUM_MIME_CHARSETS);
+#else
+					SKIP_ITEM("mm_network_charset=");
 #endif /* CHARSET_CONVERSION */
 					break;
 
@@ -341,17 +351,20 @@ read_attributes_file(
 					MATCH_BOOLEAN("show_only_unread=", ATTRIB_SHOW_ONLY_UNREAD);
 					MATCH_STRING("sigfile=", ATTRIB_SIGFILE);
 					MATCH_INTEGER("sort_art_type=", ATTRIB_SORT_ART_TYPE, SORT_ARTICLES_BY_LINES_ASCEND);
-					MATCH_INTEGER("sort_threads_type=", ATTRIB_SORT_THREADS_TYPE, SORT_THREADS_BY_SCORE_DESCEND);
+					MATCH_INTEGER("sort_threads_type=", ATTRIB_SORT_THREADS_TYPE, SORT_THREADS_BY_LAST_POSTING_DATE_ASCEND);
 					break;
 
 				case 't':
 					MATCH_BOOLEAN("tex2iso_conv=", ATTRIB_TEX2ISO_CONV);
 					MATCH_INTEGER("thread_arts=", ATTRIB_THREAD_ARTS, THREAD_MAX);
+					MATCH_INTEGER("thread_perc=", ATTRIB_THREAD_PERC, 100);
 					break;
 
 				case 'u':
 #ifdef CHARSET_CONVERSION
 					MATCH_STRING("undeclared_charset=", ATTRIB_UNDECLARED_CHARSET);
+#else
+					SKIP_ITEM("undeclared_charset=");
 #endif /* CHARSET_CONVERSION */
 					break;
 
@@ -456,103 +469,145 @@ do_set_attrib(
 		case ATTRIB_MAILDIR:
 			free_if_not_default(&group->attribute->maildir, tinrc.maildir);
 			SET_STRING(maildir);
+
 		case ATTRIB_SAVEDIR:
 			free_if_not_default(&group->attribute->savedir, tinrc.savedir);
 			SET_STRING(savedir);
+
 		case ATTRIB_SAVEFILE:
 			FreeIfNeeded(group->attribute->savefile);
 			SET_STRING(savefile);
+
 		case ATTRIB_ORGANIZATION:
 			free_if_not_default(&group->attribute->organization, default_organization);
 			SET_STRING(organization);
+
 		case ATTRIB_FROM:
 			free_if_not_default(&group->attribute->from, tinrc.mail_address);
 			SET_STRING(from);
+
 		case ATTRIB_SIGFILE:
 			free_if_not_default(&group->attribute->sigfile, tinrc.sigfile);
 			SET_STRING(sigfile);
+
 		case ATTRIB_FOLLOWUP_TO:
 			FreeIfNeeded(group->attribute->followup_to);
 			SET_STRING(followup_to);
+
 		case ATTRIB_AUTO_SELECT:
 			SET_INTEGER(auto_select);
+
 		case ATTRIB_AUTO_SAVE:
 			SET_INTEGER(auto_save);
+
 		case ATTRIB_BATCH_SAVE:
 			SET_INTEGER(batch_save);
+
 		case ATTRIB_DELETE_TMP_FILES:
 			SET_INTEGER(delete_tmp_files);
+
 		case ATTRIB_SHOW_ONLY_UNREAD:
 			SET_INTEGER(show_only_unread);
+
 		case ATTRIB_THREAD_ARTS:
 			SET_INTEGER(thread_arts);
+
+		case ATTRIB_THREAD_PERC:
+			SET_INTEGER(thread_perc);
+
 		case ATTRIB_SHOW_AUTHOR:
 			SET_INTEGER(show_author);
+
 		case ATTRIB_SHOW_INFO:
 			SET_INTEGER(show_info);
+
 		case ATTRIB_SORT_ART_TYPE:
 			SET_INTEGER(sort_art_type);
+
 		case ATTRIB_SORT_THREADS_TYPE:
 			SET_INTEGER(sort_threads_type);
+
 		case ATTRIB_POST_PROC_TYPE:
 			SET_INTEGER(post_proc_type);
+
 		case ATTRIB_QUICK_KILL_HEADER:
 			SET_INTEGER(quick_kill_header);
+
 		case ATTRIB_QUICK_KILL_SCOPE:
 			FreeIfNeeded(group->attribute->quick_kill_scope);
 			SET_STRING(quick_kill_scope);
+
 		case ATTRIB_QUICK_KILL_EXPIRE:
 			SET_INTEGER(quick_kill_expire);
+
 		case ATTRIB_QUICK_KILL_CASE:
 			SET_INTEGER(quick_kill_case);
+
 		case ATTRIB_QUICK_SELECT_HEADER:
 			SET_INTEGER(quick_select_header);
+
 		case ATTRIB_QUICK_SELECT_SCOPE:
 			FreeIfNeeded(group->attribute->quick_select_scope);
 			SET_STRING(quick_select_scope);
+
 		case ATTRIB_QUICK_SELECT_EXPIRE:
 			SET_INTEGER(quick_select_expire);
+
 		case ATTRIB_QUICK_SELECT_CASE:
 			SET_INTEGER(quick_select_case);
+
 		case ATTRIB_MAILING_LIST:
 			FreeIfNeeded(group->attribute->mailing_list);
 			SET_STRING(mailing_list);
+
 #ifdef CHARSET_CONVERSION
 		case ATTRIB_MM_NETWORK_CHARSET:
 			SET_INTEGER(mm_network_charset);
+
 		case ATTRIB_UNDECLARED_CHARSET:
 			FreeIfNeeded(group->attribute->undeclared_charset);
 			SET_STRING(undeclared_charset);
 #endif /* CHARSET_CONVERSION */
+
 		case ATTRIB_X_HEADERS:
 			FreeIfNeeded(group->attribute->x_headers);
 			SET_STRING(x_headers);
+
 		case ATTRIB_X_BODY:
 			FreeIfNeeded(group->attribute->x_body);
 			SET_STRING(x_body);
+
 		case ATTRIB_X_COMMENT_TO:
 			SET_INTEGER(x_comment_to);
+
 		case ATTRIB_FCC:
 			FreeIfNeeded(group->attribute->fcc);
 			SET_STRING(fcc);
+
 		case ATTRIB_NEWS_QUOTE:
 			free_if_not_default(&group->attribute->news_quote_format, tinrc.news_quote_format);
 			SET_STRING(news_quote_format);
+
 		case ATTRIB_QUOTE_CHARS:
 			free_if_not_default(&group->attribute->quote_chars, tinrc.quote_chars);
 			SET_STRING(quote_chars);
+
 		case ATTRIB_MIME_TYPES_TO_SAVE:
 			FreeIfNeeded(group->attribute->mime_types_to_save);
 			SET_STRING(mime_types_to_save);
+
 		case ATTRIB_MIME_FORWARD:
 			SET_INTEGER(mime_forward);
+
 #ifdef HAVE_ISPELL
 		case ATTRIB_ISPELL:
 			FreeIfNeeded(group->attribute->ispell);
 			SET_STRING(ispell);
 #endif /* HAVE_ISPELL */
+
 		case ATTRIB_TEX2ISO_CONV:
 			SET_INTEGER(tex2iso_conv);
+
 		default:
 			break;
 	}
@@ -577,7 +632,7 @@ write_attributes_file(
 
 	new_file = get_tmpfilename(file);
 
-	if ((fp = fopen(new_file, "w" FOPEN_OPTS)) == NULL) {
+	if ((fp = fopen(new_file, "w")) == NULL) {
 		error_message(_(txt_filesystem_full_backup), ATTRIBUTES_FILE);
 		free(new_file);
 		return;
@@ -621,6 +676,7 @@ write_attributes_file(
 		fprintf(fp, "%d=%s, ", i, _(txt_threading[i]));
 	}
 	fprintf(fp, "\n");
+	fprintf(fp, _("#  thread_perc=NUM\n"));
 	fprintf(fp, _("#  show_author=NUM\n"));
 	fprintf(fp, "#    %d=%s, %d=%s, %d=%s, %d=%s\n",
 		SHOW_FROM_NONE, _(txt_show_from[SHOW_FROM_NONE]),
@@ -656,6 +712,9 @@ write_attributes_file(
 		SORT_THREADS_BY_NOTHING, _(txt_sort_t_type[SORT_THREADS_BY_NOTHING]),
 		SORT_THREADS_BY_SCORE_DESCEND, _(txt_sort_t_type[SORT_THREADS_BY_SCORE_DESCEND]),
 		SORT_THREADS_BY_SCORE_ASCEND, _(txt_sort_t_type[SORT_THREADS_BY_SCORE_ASCEND]));
+	fprintf(fp, "#    %d=%s, %d=%s\n",
+		SORT_THREADS_BY_LAST_POSTING_DATE_DESCEND, _(txt_sort_t_type[SORT_THREADS_BY_LAST_POSTING_DATE_DESCEND]),
+		SORT_THREADS_BY_LAST_POSTING_DATE_ASCEND, _(txt_sort_t_type[SORT_THREADS_BY_LAST_POSTING_DATE_ASCEND]));
 	fprintf(fp, _("#  post_proc_type=NUM\n"));
 	fprintf(fp, "#    %d=%s, %d=%s, %d=%s\n",
 		POST_PROC_NO, _(txt_post_process_type[POST_PROC_NO]),
@@ -696,7 +755,7 @@ write_attributes_file(
 	/*
 	 * Add some useful defaults if no attributes file currently exists
 	 */
-	if ((infp = fopen(file, "r" FOPEN_OPTS)) == NULL) {
+	if ((infp = fopen(file, "r")) == NULL) {
 		fprintf(fp, _("# include extra headers\n"));
 		fprintf(fp, "scope=*\n");
 		/*
@@ -709,10 +768,11 @@ write_attributes_file(
 		fprintf(fp, "scope=*sources*\n");
 		fprintf(fp, "post_proc_type=%d\n\n", POST_PROC_SHAR);
 
-		fprintf(fp, _("# in *binaries* do full post processing, remove tmp files\n"));
-		fprintf(fp, _("# and set Followup-To: poster\n"));
+		fprintf(fp, _("# in *binaries* do full post processing but no TeX2ISO conversion,\n"));
+		fprintf(fp, _("# remove tmp files and set Followup-To: poster\n"));
 		fprintf(fp, "scope=*binaries*\n");
 		fprintf(fp, "post_proc_type=%d\n", POST_PROC_YES);
+		fprintf(fp, "tex2iso_conv=OFF\n");
 		fprintf(fp, "delete_tmp_files=ON\n");
 		fprintf(fp, "followup_to=poster\n\n");
 	} else {
@@ -738,7 +798,8 @@ write_attributes_file(
 		error_message(_(txt_filesystem_full), ATTRIBUTES_FILE);
 	else if (copy_ok)
 		rename_file(new_file, file);
-	else unlink (new_file);
+	else
+		unlink (new_file);
 
 	free(new_file);
 	return;
@@ -767,6 +828,7 @@ write_attributes_file(
 #	endif /* HAVE_ISPELL */
 		fprintf(fp, "show_only_unread=%s\n", print_boolean(attr->show_only_unread));
 		fprintf(fp, "thread_arts=%d\n", attr->thread_arts);
+		fprintf(fp, "thread_perc=%d\n", attr->thread_perc);
 		fprintf(fp, "auto_select=%s\n", print_boolean(attr->auto_select));
 		fprintf(fp, "auto_save=%s\n", print_boolean(attr->auto_save));
 		fprintf(fp, "batch_save=%s\n", print_boolean(attr->batch_save));
@@ -859,6 +921,7 @@ dump_attributes(
 #		endif /* HAVE_ISPELL */
 		fprintf(stderr, "\tshow_only_unread=%s\n", print_boolean(group->attribute->show_only_unread));
 		fprintf(stderr, "\tthread_arts=%d\n", group->attribute->thread_arts);
+		fprintf(stderr, "\tthread_perc=%d\n", group->attribute->thread_perc);
 		fprintf(stderr, "\tauto_select=%s\n", print_boolean(group->attribute->auto_select));
 		fprintf(stderr, "\tauto_save=%s\n", print_boolean(group->attribute->auto_save));
 		fprintf(stderr, "\tbatch_save=%s\n", print_boolean(group->attribute->batch_save));
