@@ -3,7 +3,7 @@
  *  Module    : cook.c
  *  Author    : J. Faultless
  *  Created   : 2000-03-08
- *  Updated   : 2005-07-20
+ *  Updated   : 2006-05-30
  *  Notes     : Split from page.c
  *
  * Copyright (c) 2000-2006 Jason Faultless <jason@altarstone.com>
@@ -59,6 +59,9 @@ static t_bool header_wanted(const char *line);
 static t_part *new_uue(t_part **part, char *name);
 static void process_text_body_part(t_bool wrap_lines, FILE *in, t_part *part, int hide_uue, int tabs);
 static void put_cooked(size_t buf_len, t_bool wrap_lines, int flags, const char *fmt, ...);
+#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+	static t_bool wexpand_ctrl_chars(wchar_t **wline, size_t *length, size_t lcook_width);
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 #ifdef DEBUG_ART
 	static void dump_cooked(void);
 #endif /* DEBUG_ART */
@@ -82,60 +85,109 @@ expand_ctrl_chars(
 	int *length,
 	size_t lcook_width)
 {
+	t_bool ctrl_L = FALSE;
+#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+	wchar_t *wline = char2wchar_t(*line);
+	size_t wlen;
+
+	/*
+	 * remove the assert() before release
+	 * it should help us find problems with wide-char strings
+	 * in the development branch
+	 */
+	assert (wline != NULL);
+	wlen = wcslen(wline);
+	ctrl_L = wexpand_ctrl_chars(&wline, &wlen, lcook_width);
+	free(*line);
+	*line = wchar_t2char(wline);
+	free(wline);
+	assert (line != NULL);
+	*length = strlen(*line);
+#else
 	int curr_len = LEN;
 	int i = 0, j;
 	char *buf = my_malloc(curr_len);
 	char *c;
-	t_bool ctrl_L = FALSE, resize = FALSE;
 
 	c = *line;
 	while (*c) {
-		if (resize) {
+		if (i > curr_len - 3) {
 			curr_len <<= 1;
 			buf = my_realloc(buf, curr_len);
-			resize = FALSE;
 		}
-		if (*c == '\t') { /* expand tabs */
+		if (*c == '\t') { 		/* expand tabs */
 /*			j = ((i + lcook_width) / lcook_width) * lcook_width; */
 			j = i + lcook_width - (i % lcook_width);
-			if (j > curr_len - 2) {
-				resize = TRUE;
-				continue;
-			}
 			for (; i < j; i++)
 				buf[i] = ' ';
+		} else if (((*c) & 0xFF) < ' ' && *c != '\n' && (!IS_LOCAL_CHARSET("Big5") || *c != 27)) {	/* literal ctrl chars */
+			buf[i++] = '^';
+			buf[i++] = ((*c) & 0xFF) + '@';
+			if (*c == '\f')		/* ^L detected */
+				ctrl_L = TRUE;
 		} else {
-			if (((*c) & 0xFF) < ' ' && *c != '\n' && (!IS_LOCAL_CHARSET("Big5") || *c != 27)) {	/* literal ctrl chars */
-				if (i > curr_len - 4) {
-					resize = TRUE;
-					continue;
-				}
-				buf[i++] = '^';
-				buf[i++] = ((*c) & 0xFF) + '@';
-				if (*c == '\f')	/* ^L detected */
-					ctrl_L = TRUE;
-			} else {
-				if (i > curr_len - 3) {
-					resize = TRUE;
-					continue;
-				}
+			if (!my_isprint(*c) && *c != '\n')
+				buf[i++] = '?';
+			else
 				buf[i++] = *c;
-			}
 		}
 		c++;
 	}
-	/* put_cooked() requires a newline at the end of the line */
-	if (buf[i - 1] != '\n')
-		buf[i++] = '\n';	/* Force last char of string to be \n */
 	buf[i] = '\0';
 	*length = i + 1;
 	*line = my_realloc(*line, *length);
 	strcpy(*line, buf);
 	free(buf);
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 	return ctrl_L;
 }
 
 
+#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+static t_bool
+wexpand_ctrl_chars(
+	wchar_t **wline,
+	size_t *length,
+	size_t lcook_width)
+{
+	size_t cur_len = LEN, i = 0, j;
+	wchar_t *wbuf = my_malloc(cur_len * sizeof(wchar_t));
+	wchar_t *wc;
+	t_bool ctrl_L = FALSE;
+
+	wc = *wline;
+	while (*wc) {
+		if (i > cur_len - 3) {
+			cur_len <<= 1;
+			wbuf = my_realloc(wbuf, cur_len * sizeof(wchar_t));
+		}
+		if (*wc == '\t') {		/* expand_tabs */
+			j = i + lcook_width - (i % lcook_width);
+			for (; i < j; i++)
+				wbuf[i] = ' ';
+		} else if (*wc  < ' ' && *wc != '\n' && (!IS_LOCAL_CHARSET("Big5") || *wc != 27)) {	/* literal ctrl chars */
+			wbuf[i++] = '^';
+			wbuf[i++] = *wc + '@';
+			if (*wc == '\f')	/* ^L detected */
+				ctrl_L = TRUE;
+		} else {
+			if (!iswprint((wint_t) *wc) && *wc != '\n')
+				wbuf[i++] = '?';
+			else
+				wbuf[i++] = *wc;
+		}
+		wc++;
+	}
+	wbuf[i] = '\0';
+	*length = i + 1;
+	*wline = my_realloc(*wline, *length * sizeof(wchar_t));
+	wcscpy(*wline, wbuf);
+	free(wbuf);
+	return ctrl_L;
+}
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
+
+
 /*
  * Output text to the cooked stream. Wrap lines as necessary.
  * Update the line count and the array of line offsets
@@ -355,6 +407,7 @@ process_text_body_part(
 	int size_offsets = ARRAY_SIZE(offsets);
 	t_bool in_sig = FALSE;			/* Set when in sig portion */
 	t_bool in_uue = FALSE;			/* Set when in uuencoded section */
+	t_bool verbatim = FALSE;		/* Set when in verbatim section */
 	t_bool is_uubody;				/* Set when current line looks like a uuencoded line */
 	t_part *curruue = NULL;
 
@@ -420,103 +473,111 @@ process_text_body_part(
 
 		len = (int) strlen(line);
 
-		/*
-		 * Detect and skip signatures if necessary
-		 */
-		if (!in_sig) {
-			if (strcmp(line, SIGDASHES) == 0) {
-				in_sig = TRUE;
+		/* look for verbatim marks */
+		if (!in_sig && !in_uue && !verbatim && MATCH_REGEX(verbatim_begin_regex, line, len))
+			verbatim = TRUE;
+		if (verbatim && MATCH_REGEX(verbatim_end_regex, line, len))
+			verbatim = FALSE;
+
+		if (!verbatim) {
+			/*
+			 * Detect and skip signatures if necessary
+			 */
+			if (!in_sig) {
+				if (strcmp(line, SIGDASHES) == 0) {
+					in_sig = TRUE;
+					if (in_uue) {
+						in_uue = FALSE;
+						if (hide_uue)
+							PUT_UUE(curruue, _(txt_incomplete));
+					}
+				}
+			}
+
+			if (in_sig && !tinrc.show_signatures)
+				continue;					/* No further processing needed */
+
+			/*
+			 * Detect and process uuencoded sections
+			 * Look for the start or the end of a uuencoded section
+			 *
+			 * TODO: look for a tailing size line after end (non standard
+			 *       extension)?
+			 */
+			if (pcre_exec(uubegin_regex.re, uubegin_regex.extra, line, len, 0, 0, offsets, size_offsets) != PCRE_ERROR_NOMATCH) {
+				in_uue = TRUE;
+				curruue = new_uue(&part, line + offsets[1]);
+				if (hide_uue)
+					continue;				/* Don't cook the 'begin' line */
+			} else if (strncmp(line, "end\n", 4) == 0) {
 				if (in_uue) {
 					in_uue = FALSE;
-					if (hide_uue)
-						PUT_UUE(curruue, _(txt_incomplete));
+					if (hide_uue) {
+						PUT_UUE(curruue, "");
+						continue;			/* Don't cook the 'end' line */
+					}
 				}
 			}
-		}
 
-		if (in_sig && !tinrc.show_signatures)
-			continue;					/* No further processing needed */
-
-		/*
-		 * Detect and process uuencoded sections
-		 * Look for the start or the end of a uuencoded section
-		 *
-		 * TODO: look for a tailing size line after end (non standard
-		 *       extension)?
-		 */
-		if (pcre_exec(uubegin_regex.re, uubegin_regex.extra, line, len, 0, 0, offsets, size_offsets) != PCRE_ERROR_NOMATCH) {
-			in_uue = TRUE;
-			curruue = new_uue(&part, line + offsets[1]);
-			if (hide_uue)
-				continue;				/* Don't cook the 'begin' line */
-		} else if (strncmp(line, "end\n", 4) == 0) {
-			if (in_uue) {
-				in_uue = FALSE;
-				if (hide_uue) {
-					PUT_UUE(curruue, "");
-					continue;			/* Don't cook the 'end' line */
-				}
-			}
-		}
-
-		/*
-		 * See if this line looks like a uuencoded 'body' line
-		 */
-		is_uubody = FALSE;
-
-		if (MATCH_REGEX (uubody_regex, line, len)) {
-			int sum = (((*line) - ' ') & 077) * 4 / 3;		/* uuencode octet checksum */
-
-			/* sum = 0 in a uubody only on the last line, a single ` */
-			if (sum == 0 && len == 1 + 1)			/* +1 for the \n */
-				is_uubody = TRUE;
-			else if (len == sum + 1 + 1)
-				is_uubody = TRUE;
-#ifdef DEBUG_ART
-			if (debug == 2)
-				fprintf(stderr, "%s sum=%d len=%d (%s)\n", bool_unparse(is_uubody), sum, len, line);
-#endif /* DEBUG_ART */
-		}
-
-		if (in_uue) {
-			if (is_uubody)
-				curruue->line_count++;
-			else {
-				if (line[0] == '\n') {		/* Blank line in a uubody - definitely a failure */
-					/* fprintf(stderr, "not a uue line while reading a uue body?\n"); */
-					in_uue = FALSE;
-					if (hide_uue)
-						/* don't continue here, so we see the line that 'broke' in_uue */
-						PUT_UUE(curruue, _(txt_incomplete));
-				}
-			}
-		} else {
 			/*
-			 * UUE_ALL = 'Try harder' - we never saw a begin line, but useful
-			 * when uue sections are split across > 1 article
+			 * See if this line looks like a uuencoded 'body' line
 			 */
-			if (is_uubody && hide_uue == UUE_ALL) {
-				char name[] = N_("(unknown)");
+			is_uubody = FALSE;
 
-				curruue = new_uue(&part, name);
-				curruue->line_count++;
-				in_uue = TRUE;
-				continue;
+			if (MATCH_REGEX(uubody_regex, line, len)) {
+				int sum = (((*line) - ' ') & 077) * 4 / 3;		/* uuencode octet checksum */
+
+				/* sum = 0 in a uubody only on the last line, a single ` */
+				if (sum == 0 && len == 1 + 1)			/* +1 for the \n */
+					is_uubody = TRUE;
+				else if (len == sum + 1 + 1)
+					is_uubody = TRUE;
+#ifdef DEBUG_ART
+				if (debug == 2)
+					fprintf(stderr, "%s sum=%d len=%d (%s)\n", bool_unparse(is_uubody), sum, len, line);
+#endif /* DEBUG_ART */
 			}
+
+			if (in_uue) {
+				if (is_uubody)
+					curruue->line_count++;
+				else {
+					if (line[0] == '\n') {		/* Blank line in a uubody - definitely a failure */
+						/* fprintf(stderr, "not a uue line while reading a uue body?\n"); */
+						in_uue = FALSE;
+						if (hide_uue)
+							/* don't continue here, so we see the line that 'broke' in_uue */
+							PUT_UUE(curruue, _(txt_incomplete));
+					}
+				}
+			} else {
+				/*
+				 * UUE_ALL = 'Try harder' - we never saw a begin line, but useful
+				 * when uue sections are split across > 1 article
+				 */
+				if (is_uubody && hide_uue == UUE_ALL) {
+					char name[] = N_("(unknown)");
+
+					curruue = new_uue(&part, name);
+					curruue->line_count++;
+					in_uue = TRUE;
+					continue;
+				}
+			}
+
+			/*
+			 * Skip output if we're hiding uue or the sig
+			 */
+			if (in_uue && hide_uue)
+				continue;	/* No further processing needed */
 		}
 
-		/*
-		 * Skip output if we're hiding uue or the sig
-		 */
-		if (in_uue && hide_uue)
-			continue;	/* No further processing needed */
-
-		flags = in_sig ? C_SIG : C_BODY;
+		flags = verbatim ? 0 : in_sig ? C_SIG : C_BODY;
 
 		/*
-		 * Don't do any further handling of uue lines - the data is binary after all
+		 * Don't do any further handling of uue || verbatim lines
 		 */
-		if (in_uue) {
+		if (in_uue || verbatim) {
 			put_cooked(max_line_len, wrap_lines, flags, "%s", line);
 			continue;
 		}
@@ -543,13 +604,6 @@ process_text_body_part(
 		if (MATCH_REGEX(news_regex, line, len))
 			flags |= C_NEWS;
 
-		/*
-		 * Basically, c_b2p() does: if (!(my_isprint(*c) || *c==8 || *c==9 || *c==12))
-		 * It is only used here
-		 * How about if !isprint() && !isctrl() - expand_ctrl_chars is done at display time.
-		 * TODO: integrate into expand_ctrl_chars
-		 */
-		convert_body2printable(line);
 		if (expand_ctrl_chars(&line, &max_line_len, tabs))
 			flags |= C_CTRLL;				/* Line contains form-feed */
 		put_cooked(max_line_len, wrap_lines && (!IS_LOCAL_CHARSET("Big5")), flags, "%s", line);
@@ -683,7 +737,7 @@ cook_article(
 
 		if (header_wanted(line)) {	/* Put cooked data */
 			int i = LEN;
-			char *l = my_strdup(convert_body2printable(rfc1522_decode(line)));	/* FIXME: don't decode addr-part of From:/Cc:/ etc.pp. */
+			char *l = my_strdup(rfc1522_decode(line));	/* FIXME: don't decode addr-part of From:/Cc:/ etc.pp. */
 
 			header_put = TRUE;
 			expand_ctrl_chars(&l, &i, tabs);
