@@ -3,7 +3,7 @@
  *  Module    : curses.c
  *  Author    : D. Taylor & I. Lea
  *  Created   : 1986-01-01
- *  Updated   : 2004-07-20
+ *  Updated   : 2006-02-15
  *  Notes     : This is a screen management library borrowed with permission
  *              from the Elm mail system. This library was hacked to provide
  *              what tin needs.
@@ -42,22 +42,11 @@ t_bool have_linescroll = TRUE;	/* USE_CURSES always allows line scrolling */
 #	undef	sinix
 #endif /* !ns32000 */
 
-#ifdef VMS
-#	include <descrip.h>
-#	include <iodef.h>
-#	include <ssdef.h>
-#	include <dvidef.h>
-#	ifdef __GNUC__ /* M.St. 22.01.98 */
-#		include <vms/sys$routines.h>
-#		include <vms/lib$routines.h>
-#	endif /* __GNUC__ */
-#endif /* VMS */
-
 #define DEFAULT_LINES_ON_TERMINAL	24
 #define DEFAULT_COLUMNS_ON_TERMINAL	80
 
 int cLINES = DEFAULT_LINES_ON_TERMINAL - 1;
-int cCOLS  = DEFAULT_COLUMNS_ON_TERMINAL;
+int cCOLS = DEFAULT_COLUMNS_ON_TERMINAL;
 int _hp_glitch = FALSE;		/* stdout not erased by overwriting on HP terms */
 static int _inraw = FALSE;	/* are we IN rawmode? */
 static int xclicks = FALSE;	/* do we have an xterm? */
@@ -65,89 +54,39 @@ t_bool have_linescroll = FALSE;
 
 #define TTYIN	0
 
-#ifdef HAVE_CONFIG_H
-
-#	if defined(HAVE_TERMIOS_H) && defined(HAVE_TCGETATTR) && defined(HAVE_TCSETATTR)
-#		ifdef HAVE_IOCTL_H
-#			include <ioctl.h>
-#		else
-#			ifdef HAVE_SYS_IOCTL_H
-#				include <sys/ioctl.h>
-#			endif /* HAVE_SYS_IOCTL_H */
-#		endif /* HAVE_IOCTL_H */
-#		if !defined(sun) || !defined(NL0)
-#			include <termios.h>
-#		endif /* !sun || !NL0 */
-#		define USE_POSIX_TERMIOS 1
-#		define TTY struct termios
+#if defined(HAVE_TERMIOS_H) && defined(HAVE_TCGETATTR) && defined(HAVE_TCSETATTR)
+#	ifdef HAVE_IOCTL_H
+#		include <ioctl.h>
 #	else
-#		ifdef HAVE_TERMIO_H
-#			include <termio.h>
-#			define USE_TERMIO 1
-#			define TTY struct termio
-#		else
-#			ifdef HAVE_SGTTY_H
-#				include <sgtty.h>
-#				define USE_SGTTY 1
-#				define TTY struct sgttyb
+#		ifdef HAVE_SYS_IOCTL_H
+#			include <sys/ioctl.h>
+#		endif /* HAVE_SYS_IOCTL_H */
+#	endif /* HAVE_IOCTL_H */
+#	if !defined(sun) || !defined(NL0)
+#		include <termios.h>
+#	endif /* !sun || !NL0 */
+#	define USE_POSIX_TERMIOS 1
+#	define TTY struct termios
+#else
+#	ifdef HAVE_TERMIO_H
+#		include <termio.h>
+#		define USE_TERMIO 1
+#		define TTY struct termio
+#	else
+#		ifdef HAVE_SGTTY_H
+#			include <sgtty.h>
+#			define USE_SGTTY 1
+#			define TTY struct sgttyb
 /*
 	#			else
 	#				error "No termios.h, termio.h or sgtty.h found"
 */
-#			endif /* HAVE_SGTTY_H */
-#		endif /* HAVE_TERMIO_H */
-#	endif /* HAVE_TERMIOS_H && HAVE_TCGETATTR && HAVE_TCSETATTR */
+#		endif /* HAVE_SGTTY_H */
+#	endif /* HAVE_TERMIO_H */
+#endif /* HAVE_TERMIOS_H && HAVE_TCGETATTR && HAVE_TCSETATTR */
 
 static TTY _raw_tty, _original_tty;
 
-#else	/* FIXME: prune the non-autoconf'd stuff */
-
-#	if (defined(COHERENT) || defined(BSD)
-#		ifdef BSD4_1
-#			include <termio.h>
-#			define USE_TERMIO 1
-#		else
-#			include <sgtty.h>
-#			define USE_SGTTY 1
-#		endif /* BSD4_1 */
-#	else
-#		if !defined(SYSV)
-#			ifdef MINIX
-#				include <sgtty.h>
-#				define USE_SGTTY 1
-#			else
-#				ifndef QNX42
-#					ifdef sinix
-#						include <termios.h>
-#						define USE_POSIX_TERMIOS 1
-#					else
-#						ifdef VMS
-#							include <curses.h>
-#						else
-#							include <termio.h>
-#							define USE_TERMIO 1
-#						endif /* VMS */
-#					endif /* sinix */
-#				endif /* !QNX42 */
-#			endif /* MINIX */
-#		endif /* !SYSV */
-#	endif /* COHERENT || BSD */
-
-#	ifndef VMS
-#		if (defined(BSD) || defined(MINIX)
-#			define USE_SGTTY 1
-struct sgttyb _raw_tty, _original_tty;
-#		else
-#			if defined(HAVE_TERMIOS_H) || defined(sinix)
-#				define USE_POSIX_TERMIOS 1
-struct termios _raw_tty, _original_tty;
-#			else
-#				define USE_TERMIO 1
-struct termio _raw_tty, _original_tty;
-#			endif /* HAVE_TERMIOS_H || sinix */
-#		endif /* BSD || MINIX */
-#	endif /* !VMS */
-#endif /* HAVE_CONFIG_H */
 
 #ifndef USE_SGTTY
 #	define USE_SGTTY 0
@@ -335,9 +274,9 @@ get_termcaps(
 	for (n = 0; n < ARRAY_SIZE(table); n++) {
 		*(table[n].value) = TGETSTR(table[n].capname, &ptr);
 	}
-	_lines          = TGETNUM(dCAPNAME("li", "lines"));
-	_columns        = TGETNUM(dCAPNAME("co", "cols"));
-	_hp_glitch      = TGETFLAG(dCAPNAME("xs", "xhp"));
+	_lines = TGETNUM(dCAPNAME("li", "lines"));
+	_columns = TGETNUM(dCAPNAME("co", "cols"));
+	_hp_glitch = TGETFLAG(dCAPNAME("xs", "xhp"));
 
 #	if defined(USE_TERMCAP) && defined(HAVE_EXTERN_TCAP_PC)
 	t = TGETSTR(CAPNAME("pc", "pad"), &p);
@@ -347,10 +286,10 @@ get_termcaps(
 
 	if (STRCMPEQ(the_termname, "xterm")) {
 		static char x_init[] = "\033[?9h";
-		static char x_end[]  = "\033[?9l";
+		static char x_end[] = "\033[?9l";
 		xclicks = TRUE;
-		_xclickinit	= x_init;
-		_xclickend	= x_end;
+		_xclickinit = x_init;
+		_xclickend = x_end;
 	}
 
 	if (NO_CAP(_clearscreen)) {
@@ -418,113 +357,33 @@ InitScreen(
 	 * we're going to assume a terminal here...
 	 */
 
-	_clearscreen	= "\033[1;1H\033[J";
-	_moveto		= "\033[%d;%dH";	/* not a termcap string! */
-	_cleartoeoln	= "\033[K";
-	_setinverse	= "\033[7m";
-	_clearinverse	= "\033[0m";
-	_setunderline	= "\033[4m";
-	_clearunderline	= "\033[0m";
-	_keypadlocal	= "";
-	_keypadxmit	= "";
-#	ifdef VMS
-	_cleartoeos	= "\033[J";
-	_terminalinit	= NULL;
-	_terminalend	= "";
-#	endif /* VMS */
+	_clearscreen = "\033[1;1H\033[J";
+	_moveto = "\033[%d;%dH";	/* not a termcap string! */
+	_cleartoeoln = "\033[K";
+	_setinverse = "\033[7m";
+	_clearinverse = "\033[0m";
+	_setunderline = "\033[4m";
+	_clearunderline = "\033[0m";
+	_keypadlocal = "";
+	_keypadxmit = "";
 	/* needed for word highlighting */
-	_reset		= "\033[0m";
-	_reversevideo	= "\033[7m";
-	_blink		= "\033[5m";
-	_dim		= "\033[2m";
-	_bold		= "\033[1m";
+	_reset = "\033[0m";
+	_reversevideo = "\033[7m";
+	_blink = "\033[5m";
+	_dim = "\033[2m";
+	_bold = "\033[1m";
 
 	_lines = _columns = -1;
 
-	if ((ptr = getenv("LINES")) != 0) {
+	if ((ptr = getenv("LINES")) != 0)
 		_lines = atol(ptr);
-	}
-	if ((ptr = getenv("COLUMNS")) != 0) {
+
+	if ((ptr = getenv("COLUMNS")) != 0)
 		_columns = atol(ptr);
-	}
 
 	/*
 	 * If that failed, try get a response from the console itself
 	 */
-#	ifdef VMS /* moved from below InitWin() M.St. 22.01.98 */
-	{
-		int input_chan, status;
-		int item_code, eightbit;
-		struct sensemode {
-			short status;
-			unsigned char xmit_baud;
-			unsigned char rcv_baud;
-			unsigned char crfill;
-			unsigned char lffill;
-			unsigned char parity;
-			unsigned char unused;
-			char class;
-			char type;
-			short scr_wid;
-			unsigned long tt_char : 24, scr_len : 8;
-			unsigned long tt2_char;
-		} tty;
-		$DESCRIPTOR(input_dsc, "TT");
-
-		status = SYS$ASSIGN(&input_dsc, &input_chan, 0, 0);
-		if (!(status & 1))
-			LIB$STOP(status);
-		SYS$QIOW(0, input_chan, IO$_SENSEMODE, &tty, 0, 0, &tty.class, 12, 0, 0, 0, 0);
-		item_code = DVI$_TT_EIGHTBIT;
-		status = LIB$GETDVI(&item_code, &input_chan, 0, &eightbit, 0, 0);
-		_columns = tty.scr_wid;
-		_lines = tty.scr_len;
-
-		if (eightbit) { /* if using eightbit then use CSI (octal 233) rather than ESC "[" */
-			_clearscreen = "\2331;1H\233J";
-			_moveto = "\233%d;%dH"; /* not a termcap string! */
-			_cleartoeoln = "\233K";
-			_cleartoeos = "\233J";
-			_setinverse = "\2337m";
-			_clearinverse = "\2330m";
-			_setunderline = "\2334m";
-			_clearunderline = "\2330m";
-			_keypadlocal = "";
-			_keypadxmit = "";
-		} else {
-			_clearscreen = "\033[1;1H\033[J";
-			_moveto = "\033[%d;%dH";	/* not a termcap string! */
-			_cleartoeoln = "\033[K";
-			_cleartoeos = "\033[J";
-			_setinverse = "\033[7m";
-			_clearinverse = "\033[0m";
-			_setunderline = "\033[4m";
-			_clearunderline = "\033[0m";
-			_keypadlocal = "";
-			_keypadxmit = "";
-		}
-#		ifdef HAVE_IS_XTERM
-		if (is_xterm()) {
-			xclicks = TRUE;
-			if (!eightbit) {
-				_xclickinit = "\033[?9h";
-				_xclickend  = "\033[?9l";
-			}
-#			if 0
-			else {
-				/*
-				 * These are the settings for a DECterm but the reply can't easily be parsed
-				 * Reply is of the form - CSI Pe ; Pb ; Pr ; Pc & w
-				 * Where Pe is the event, Pb the button, Pr and Pc the row and column
-				 */
-				_xclickinit = "\2331;2'z";
-				_xclickend = "\2330;0'z";
-			}
-#			endif /* 0 */
-		}
-#		endif /* HAVE_IS_XTERM */
-	}
-#	endif /* VMS */
 
 	if (_lines < MIN_LINES_ON_TERMINAL || _columns < MIN_COLUMNS_ON_TERMINAL) {
 		my_fprintf(stderr, _(txt_screen_too_small), tin_progname);
@@ -808,38 +667,28 @@ void
 Raw(
 	int state)
 {
-#ifdef VMS
-	if (!state && _inraw) {
-/*		vmsnoraw(); */
-		_inraw = 0;
-	} else if (state && !_inraw) {
-/*		vmsraw(); */
-		_inraw = 1;
-	}
-#else
 	if (!state && _inraw) {
 		SET_TTY(&_original_tty);
 		_inraw = 0;
 	} else if (state && !_inraw) {
 		GET_TTY(&_original_tty);
 		GET_TTY(&_raw_tty);
-#		if USE_SGTTY
+#if USE_SGTTY
 		_raw_tty.sg_flags &= ~(ECHO | CRMOD);	/* echo off */
 		_raw_tty.sg_flags |= CBREAK;		/* raw on */
-#		else
-#			ifdef __FreeBSD__
+#else
+#	ifdef __FreeBSD__
 		cfmakeraw(&_raw_tty);
 		_raw_tty.c_lflag |= ISIG;		/* for ^Z */
-#			else
+#	else
 		_raw_tty.c_lflag &= ~(ICANON | ECHO);	/* noecho raw mode */
 		_raw_tty.c_cc[VMIN] = '\01';	/* minimum # of chars to queue */
 		_raw_tty.c_cc[VTIME] = '\0';	/* minimum time to wait for input */
-#			endif /* __FreeBSD__ */
-#		endif /* USE_SGTTY */
+#	endif /* __FreeBSD__ */
+#endif /* USE_SGTTY */
 		SET_TTY(&_raw_tty);
 		_inraw = 1;
 	}
-#endif /* !VMS */
 }
 
 
@@ -1154,17 +1003,16 @@ get_arrow_key(
 	while (!input_pending(0) \
 		&& i < ((VT_ESCAPE_TIMEOUT * 1000) / SECOND_CHARACTER_DELAY))
 
-#	ifndef VMS
 	if (!input_pending(0)) {
-#			ifdef HAVE_USLEEP
+#	ifdef HAVE_USLEEP
 		int i = 0;
 
 		wait_a_while(i) {
 			usleep((unsigned long) (SECOND_CHARACTER_DELAY * 1000));
 			i++;
 		}
-#			else	/* !HAVE_USLEEP */
-#				ifdef HAVE_SELECT
+#	else	/* !HAVE_USLEEP */
+#		ifdef HAVE_SELECT
 		struct timeval tvptr;
 		int i = 0;
 
@@ -1174,8 +1022,8 @@ get_arrow_key(
 			select(0, NULL, NULL, NULL, &tvptr);
 			i++;
 		}
-#				else /* !HAVE_SELECT */
-#					ifdef HAVE_POLL
+#		else /* !HAVE_SELECT */
+#			ifdef HAVE_POLL
 		struct pollfd fds[1];
 		int i = 0;
 
@@ -1183,15 +1031,14 @@ get_arrow_key(
 			poll(fds, 0, SECOND_CHARACTER_DELAY);
 			i++;
 		}
-#					else /* !HAVE_POLL */
+#			else /* !HAVE_POLL */
 		(void) sleep(1);
-#					endif /* HAVE_POLL */
-#				endif /* HAVE_SELECT */
-#			endif /* HAVE_USLEEP */
+#			endif /* HAVE_POLL */
+#		endif /* HAVE_SELECT */
+#	endif /* HAVE_USLEEP */
 		if (!input_pending(0))
 			return prech;
 	}
-#	endif /* !VMS */
 	ch = ReadCh();
 	if (ch == '[' || ch == 'O')
 		ch = ReadCh();
