@@ -3,10 +3,10 @@
  *  Module    : feed.c
  *  Author    : I. Lea
  *  Created   : 1991-08-31
- *  Updated   : 2005-02-12
+ *  Updated   : 2006-09-02
  *  Notes     : provides same interface to mail,pipe,print,save & repost commands
  *
- * Copyright (c) 1991-2005 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2007 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -45,14 +45,6 @@
 #	endif /* !TCURSES_H */
 #endif /* DEBUG */
 
-#ifndef KEYMAP_H
-#	include "keymap.h"
-#endif /* !KEYMAP_H */
-
-#ifndef RFC2046_H
-#	include "rfc2046.h"
-#endif /* !RFC2046_H */
-
 
 static t_bool confirm;					/* only used for FEED_MAIL */
 static t_bool is_mailbox = FALSE;
@@ -74,6 +66,7 @@ struct t_counters {
  * Local prototypes
  */
 static char *get_save_filename(struct t_group *group, int function, char *filename, int filelen, int respnum);
+static t_bool expand_feed_filename(char *outpath, const char *path);
 static t_bool feed_article(int art, int function, struct t_counters *counter, t_bool use_current, const char *data, struct t_group *group);
 static t_function get_feed_key(int function, int level, struct t_group *group, struct t_art_stat *thread, int respnum);
 static t_function get_post_proc_type(void);
@@ -154,6 +147,35 @@ get_save_filename(
 }
 
 
+/*
+ * Generate a path/filename to save to, using 'path' as input.
+ * The pathname is stored in 'outpath', which should be PATH_LEN in size
+ * Expand metacharacters and use defaults as needed.
+ * Return TRUE if the path is a mailbox, or FALSE otherwise.
+ */
+static t_bool
+expand_feed_filename(
+	char *outpath,
+	const char *path)
+{
+	int ret = strfpath(path, outpath, PATH_LEN, curr_group);
+
+	/*
+	 * If no path exists or the above failed in some way, use sensible defaults
+	 * Put the generic path into 'outpath'
+	 */
+	if ((ret == 0) || !(strrchr(outpath, DIRSEP))) {
+		char buf[PATH_LEN];
+
+		if (!strfpath(curr_group->attribute->savedir, buf, sizeof(buf), curr_group))
+			joinpath(buf, homedir, DEFAULT_SAVEDIR);
+		joinpath(outpath, buf, path);
+		return FALSE;
+	} else
+		return (ret == 1);
+}
+
+
 /*
  * Find out what post-processing to perform.
  * This is not used when saving to mailboxes (we don't postprocess mailboxes)
@@ -242,7 +264,7 @@ get_feed_key(
 		case FEED_REPOST:
 			if (!can_post) {				/* Get this over with before asking any Q's */
 				info_message(_(txt_cannot_post));
-				return 0;
+				return NOT_ASSIGNED;
 			}
 			prompt = txt_repost;
 			break;
@@ -303,7 +325,7 @@ get_feed_key(
 		case GLOBAL_ABORT:
 			clear_message();
 			return GLOBAL_ABORT;
-			/* NOT REACHED */
+			/* NOTREACHED */
 			break;
 
 		default:
@@ -521,8 +543,8 @@ feed_articles(
 	struct t_group *group,
 	int respnum)
 {
-	char outpath[PATH_LEN];
 	char *prompt;
+	char outpath[PATH_LEN];
 	int art;
 	int i;
 	int saved_curr_line = -1;
@@ -633,7 +655,7 @@ feed_articles(
 				}
 
 				/* We don't postprocess mailboxen */
-				if ((is_mailbox = expand_save_filename(outpath, savefile)) == TRUE)
+				if ((is_mailbox = expand_feed_filename(outpath, savefile)) == TRUE)
 					pproc_func = POSTPROCESS_NO;
 				else {
 					if (function != FEED_AUTOSAVE && (pproc_func = get_post_proc_type()) == GLOBAL_ABORT)
@@ -677,7 +699,7 @@ feed_articles(
 							supersede = TRUE;
 							break;
 
-						case FEED_REPOST:
+						case FEED_KEY_REPOST:
 							tmp = fmt_string(_(txt_repost_group), tinrc.default_repost_group);
 							supersede = FALSE;
 							break;
