@@ -3,10 +3,10 @@
  *  Module    : global.c
  *  Author    : Jason Faultless <jason@altarstone.com>
  *  Created   : 1999-12-12
- *  Updated   : 2005-01-30
+ *  Updated   : 2005-10-19
  *  Notes     : Generic nagivation and key handling routines
  *
- * Copyright (c) 1999-2005 Jason Faultless <jason@altarstone.com>
+ * Copyright (c) 1999-2007 Jason Faultless <jason@altarstone.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,9 +41,6 @@
 #ifndef TCURSES_H
 #	include "tcurses.h"
 #endif /* !TCURSES_H */
-#ifndef KEYMAP_H
-#	include "keymap.h"
-#endif /* !KEYMAP_H */
 
 /*
  * Local prototypes
@@ -285,7 +282,7 @@ scroll_up(
 #ifdef USE_CURSES
 	do_scroll(-1);
 	currmenu->draw_item(currmenu->first);
-	 stow_cursor();
+	stow_cursor();
 	if (currmenu->curr >= currmenu->first + NOTESLINES)
 		move_to_item(currmenu->curr - 1);
 #else
@@ -360,7 +357,11 @@ handle_keypad(
 		t_function (*right_action) (void)),
 	const struct keylist keys)
 {
+#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+	wint_t ch = ReadWch();
+#else
 	int ch = ReadCh();
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 	t_function func = NOT_ASSIGNED;
 
 	switch (ch) {
@@ -368,7 +369,7 @@ handle_keypad(
 #	ifdef HAVE_KEY_PREFIX
 		case KEY_PREFIX:
 #	endif /* HAVE_KEY_PREFIX */
-			switch (get_arrow_key(ch)) {
+			switch (get_arrow_key((int) ch)) {
 				case KEYMAP_UP:
 					func = GLOBAL_LINE_UP;
 					break;
@@ -404,6 +405,7 @@ handle_keypad(
 				case KEYMAP_MOUSE:
 					if (mouse_action)
 						func = mouse_action(left_action, right_action);
+					break;
 
 				default:
 					break;
