@@ -3,10 +3,10 @@
  *  Module    : help.c
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2005-03-14
+ *  Updated   : 2006-06-28
  *  Notes     :
  *
- * Copyright (c) 1991-2005 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2007 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,9 +41,6 @@
 #ifndef TCURSES_H
 #	include "tcurses.h"
 #endif /* !TCURSES_H */
-#ifndef KEYMAP_H
-#	include "keymap.h"
-#endif /* !KEYMAP_H */
 
 
 typedef struct thp {
@@ -95,13 +92,15 @@ static t_help_page select_help_page[] = {
 	{ txt_help_title_ops, NOT_ASSIGNED },
 	{ txt_help_select_read_group, SELECT_ENTER_GROUP },
 	{ txt_help_select_next_unread_group, SELECT_ENTER_NEXT_UNREAD_GROUP },
+#ifndef NO_POSTING
 	{ txt_help_global_post, GLOBAL_POST },
 	{ txt_help_global_post_postponed, GLOBAL_POSTPONED },
+#endif /* NO_POSTING */
 	{ txt_help_empty_line, NOT_ASSIGNED },
 	{ txt_help_select_group_range, GLOBAL_SET_RANGE },
 	{ txt_help_empty_line, NOT_ASSIGNED },
-	{ txt_help_select_catchup, SELECT_CATCHUP },
-	{ txt_help_select_catchup_next_unread, SELECT_CATCHUP_NEXT_UNREAD },
+	{ txt_help_select_catchup, CATCHUP },
+	{ txt_help_select_catchup_next_unread, CATCHUP_NEXT_UNREAD },
 	{ txt_help_select_mark_group_unread, SELECT_MARK_GROUP_UNREAD },
 	{ txt_help_select_subscribe, SELECT_SUBSCRIBE },
 	{ txt_help_select_unsubscribe, SELECT_UNSUBSCRIBE },
@@ -109,6 +108,8 @@ static t_help_page select_help_page[] = {
 	{ txt_help_select_unsubscribe_pattern, SELECT_UNSUBSCRIBE_PATTERN },
 	{ txt_help_select_move_group, SELECT_MOVE_GROUP },
 	{ txt_help_empty_line, NOT_ASSIGNED },
+	{ txt_help_global_edit_filter, GLOBAL_EDIT_FILTER},
+	{ txt_help_empty_line, NOT_ASSIGNED },
 	{ txt_help_title_misc, NOT_ASSIGNED },
 	{ txt_help_select_quit, GLOBAL_QUIT },
 	{ txt_help_global_quit_tin, GLOBAL_QUIT_TIN },
@@ -175,9 +176,11 @@ static t_help_page group_help_page[] = {
 	{ txt_help_title_ops, NOT_ASSIGNED },
 	{ txt_help_thread_read_article, GROUP_READ_BASENOTE },
 	{ txt_help_article_next_unread, GROUP_NEXT_UNREAD_ARTICLE_OR_GROUP },
+#ifndef NO_POSTING
 	{ txt_help_global_post, GLOBAL_POST },
 	{ txt_help_global_post_postponed, GLOBAL_POSTPONED },
 	{ txt_help_article_repost, GROUP_REPOST },
+#endif /* NO_POSTING */
 	{ txt_help_empty_line, NOT_ASSIGNED },
 	{ txt_help_global_article_range, GLOBAL_SET_RANGE },
 	{ txt_help_empty_line, NOT_ASSIGNED },
@@ -196,10 +199,10 @@ static t_help_page group_help_page[] = {
 	{ txt_help_group_untag_thread, GROUP_UNTAG },
 	{ txt_help_empty_line, NOT_ASSIGNED },
 	{ txt_help_group_mark_thread_read, GROUP_MARK_THREAD_READ },
-	{ txt_help_group_catchup, GROUP_CATCHUP },
-	{ txt_help_group_catchup_next, GROUP_CATCHUP_NEXT_UNREAD },
-	{ txt_help_group_mark_article_unread, GROUP_MARK_ARTICLE_UNREAD },
-	{ txt_help_group_mark_thread_unread, GROUP_MARK_THREAD_UNREAD },
+	{ txt_help_group_catchup, CATCHUP },
+	{ txt_help_group_catchup_next, CATCHUP_NEXT_UNREAD },
+	{ txt_help_group_mark_article_unread, MARK_ARTICLE_UNREAD },
+	{ txt_help_group_mark_thread_unread, MARK_THREAD_UNREAD },
 	{ txt_help_empty_line, NOT_ASSIGNED },
 	{ txt_help_group_select_all, GROUP_DO_AUTOSELECT },
 	{ txt_help_group_select_thread, GROUP_SELECT_THREAD },
@@ -213,6 +216,7 @@ static t_help_page group_help_page[] = {
 	{ txt_help_article_autokill, GLOBAL_MENU_FILTER_KILL },
 	{ txt_help_article_quick_select, GLOBAL_QUICK_FILTER_SELECT },
 	{ txt_help_article_quick_kill, GLOBAL_QUICK_FILTER_KILL },
+	{ txt_help_global_edit_filter, GLOBAL_EDIT_FILTER},
 	{ txt_help_empty_line, NOT_ASSIGNED },
 	{ txt_help_title_misc, NOT_ASSIGNED },
 	{ txt_help_global_previous_menu, GLOBAL_QUIT },
@@ -266,29 +270,41 @@ static t_help_page thread_help_page[] = {
 	{ txt_help_title_ops, NOT_ASSIGNED },
 	{ txt_help_thread_read_article, THREAD_READ_ARTICLE },
 	{ txt_help_article_next_unread, THREAD_READ_NEXT_ARTICLE_OR_THREAD },
+#ifndef NO_POSTING
 	{ txt_help_global_post, GLOBAL_POST },
 	{ txt_help_global_post_postponed, GLOBAL_POSTPONED },
+#endif /* NO_POSTING */
 	{ txt_help_empty_line, NOT_ASSIGNED },
 	{ txt_help_global_article_range, GLOBAL_SET_RANGE },
 	{ txt_help_empty_line, NOT_ASSIGNED },
 	{ txt_help_global_mail, THREAD_MAIL },
 	{ txt_help_global_save, THREAD_SAVE },
 	{ txt_help_global_auto_save, THREAD_AUTOSAVE },
+#ifndef DONT_HAVE_PIPING
+	{ txt_help_global_pipe, GLOBAL_PIPE },
+#endif /* !DONT_HAVE_PIPING */
+#ifndef DISABLE_PRINTING
+	{ txt_help_global_print, GLOBAL_PRINT },
+#endif /* !DISABLE_PRINTING */
 	{ txt_help_empty_line, NOT_ASSIGNED },
 	{ txt_help_global_tag, THREAD_TAG },
 	{ txt_help_group_untag_thread, THREAD_UNTAG },
 	{ txt_help_empty_line, NOT_ASSIGNED },
 	{ txt_help_thread_mark_article_read, THREAD_MARK_ARTICLE_READ },
-	{ txt_help_thread_catchup, THREAD_CATCHUP },
-	{ txt_help_thread_catchup_next_unread, THREAD_CATCHUP_NEXT_UNREAD },
-	{ txt_help_group_mark_article_unread, GROUP_MARK_ARTICLE_UNREAD },
-	{ txt_help_group_mark_thread_unread, GROUP_MARK_THREAD_UNREAD },
+	{ txt_help_thread_catchup, CATCHUP },
+	{ txt_help_thread_catchup_next_unread, CATCHUP_NEXT_UNREAD },
+	{ txt_help_group_mark_article_unread, MARK_ARTICLE_UNREAD },
+	{ txt_help_group_mark_thread_unread, MARK_THREAD_UNREAD },
 	{ txt_help_empty_line, NOT_ASSIGNED },
 	{ txt_help_group_select_thread, THREAD_SELECT_ARTICLE },
 	{ txt_help_group_toggle_thread_selection, THREAD_TOGGLE_ARTICLE_SELECTION },
 	{ txt_help_group_reverse_thread_selection, THREAD_REVERSE_SELECTIONS },
 	{ txt_help_group_undo_thread_selection, THREAD_UNDO_SELECTIONS },
 	{ txt_help_empty_line, NOT_ASSIGNED },
+	{ txt_help_article_autoselect, GLOBAL_MENU_FILTER_SELECT },
+	{ txt_help_article_autokill, GLOBAL_MENU_FILTER_KILL },
+	{ txt_help_global_edit_filter, GLOBAL_EDIT_FILTER },
+	{ txt_help_empty_line, NOT_ASSIGNED },
 	{ txt_help_title_misc, NOT_ASSIGNED },
 	{ txt_help_global_previous_menu, GLOBAL_QUIT },
 	{ txt_help_global_quit_tin, GLOBAL_QUIT_TIN },
@@ -310,7 +326,6 @@ static t_help_page thread_help_page[] = {
 static t_help_page page_help_page[] = {
 	{ txt_help_title_navi, NOT_ASSIGNED },
 	{ txt_help_global_page_down, GLOBAL_PAGE_DOWN },
-	{ txt_help_global_page_down, PAGE_PAGE_DOWN3 },
 	{ txt_help_global_page_up, GLOBAL_PAGE_UP },
 	{ txt_help_global_line_down, GLOBAL_LINE_DOWN },
 	{ txt_help_global_line_up, GLOBAL_LINE_UP },
@@ -356,12 +371,15 @@ static t_help_page page_help_page[] = {
 	{ txt_help_article_toggle_formfeed, PAGE_REVEAL },
 	{ txt_help_empty_line, NOT_ASSIGNED },
 	{ txt_help_title_ops, NOT_ASSIGNED },
+#ifndef NO_POSTING
 	{ txt_help_global_post, GLOBAL_POST },
 	{ txt_help_global_post_postponed, GLOBAL_POSTPONED },
 	{ txt_help_article_followup, PAGE_FOLLOWUP_QUOTE },
 	{ txt_help_article_followup_no_quote, PAGE_FOLLOWUP },
 	{ txt_help_article_followup_with_header, PAGE_FOLLOWUP_QUOTE_HEADERS },
 	{ txt_help_article_repost, PAGE_REPOST },
+	{ txt_help_article_cancel, PAGE_CANCEL },
+#endif /* NO_POSTING */
 	{ txt_help_article_reply, PAGE_REPLY_QUOTE },
 	{ txt_help_article_reply_no_quote, PAGE_REPLY },
 	{ txt_help_article_reply_with_header, PAGE_REPLY_QUOTE_HEADERS },
@@ -381,16 +399,16 @@ static t_help_page page_help_page[] = {
 	{ txt_help_global_tag, PAGE_TAG },
 	{ txt_help_empty_line, NOT_ASSIGNED },
 	{ txt_help_article_mark_thread_read, PAGE_MARK_THREAD_READ },
-	{ txt_help_thread_catchup, PAGE_CATCHUP },
-	{ txt_help_thread_catchup_next_unread, PAGE_CATCHUP_NEXT_UNREAD },
-	{ txt_help_group_mark_article_unread, GROUP_MARK_ARTICLE_UNREAD },
-	{ txt_help_group_mark_thread_unread, GROUP_MARK_THREAD_UNREAD },
+	{ txt_help_thread_catchup, CATCHUP },
+	{ txt_help_thread_catchup_next_unread, CATCHUP_NEXT_UNREAD },
+	{ txt_help_group_mark_article_unread, MARK_ARTICLE_UNREAD },
+	{ txt_help_group_mark_thread_unread, MARK_THREAD_UNREAD },
 	{ txt_help_empty_line, NOT_ASSIGNED },
 	{ txt_help_article_autoselect, GLOBAL_MENU_FILTER_SELECT },
 	{ txt_help_article_autokill, GLOBAL_MENU_FILTER_KILL },
 	{ txt_help_article_quick_select, GLOBAL_QUICK_FILTER_SELECT },
 	{ txt_help_article_quick_kill, GLOBAL_QUICK_FILTER_KILL },
-	{ txt_help_article_cancel, PAGE_CANCEL },
+	{ txt_help_global_edit_filter, GLOBAL_EDIT_FILTER },
 	{ txt_help_empty_line, NOT_ASSIGNED },
 	{ txt_help_title_misc, NOT_ASSIGNED },
 	{ txt_help_article_browse_urls, PAGE_VIEW_URL },
@@ -421,19 +439,21 @@ make_help_page(
 	const t_help_page *helppage,
 	const struct keylist keys)
 {
-	char *buf;
+	char *buf = my_malloc(LEN);
+	char *last = my_malloc(LEN);
 	char key[MAXKEYLEN];
 	/*
 	 * length is only needed to pass it to expand_ctrl_chars()
 	 * we have no need for the value
 	 */
 	int length;
-
-	buf = my_malloc(LEN);
+	size_t i;
 
 	if (!helppage)
 		return;
 
+	last[0] = '\0';
+
 	while (helppage->helptext) {
 		if (helppage->func == NOT_ASSIGNED) {
 			/*
@@ -442,23 +462,24 @@ make_help_page(
 			 */
 			buf = my_realloc(buf, LEN);
 
-			if (!strlen(helppage->helptext))	/* avoid empty string translations */
-				snprintf(buf, LEN, "%s", helppage->helptext);
+			if (!strlen(helppage->helptext))	/* avoid translation of empty strings */
+				snprintf(buf, LEN, "\n");
 			else
 				snprintf(buf, LEN, "%s", _(helppage->helptext));
 			buf[LEN - 1] = '\0';
 			expand_ctrl_chars(&buf, &length, 8);
-			fprintf(fp, "%s", buf);
+			fprintf(fp, "%s\n", buf);
 		} else {
-			size_t i;
-
 			for (i = 0; i < keys.used; i++) {
-				if (keys.list[i].function == helppage->func) {
+				if (keys.list[i].function == helppage->func && keys.list[i].key) {
 					buf = my_realloc(buf, LEN);
 					snprintf(buf, LEN, "%s\t  %s", printascii(key, keys.list[i].key), _(helppage->helptext));
 					buf[LEN - 1] = '\0';
 					expand_ctrl_chars(&buf, &length, 8);
-					fprintf(fp, "%s", buf);
+					if (strcmp(last, buf)) {
+						fprintf(fp, "%s\n", buf);
+						strncpy(last, buf, LEN);
+					}
 				}
 			}
 		}
@@ -466,6 +487,7 @@ make_help_page(
 	}
 
 	free(buf);
+	free(last);
 }
 
 
@@ -534,7 +556,7 @@ show_mini_help(
 				printascii(key[0], func_to_key(SELECT_ENTER_NEXT_UNREAD_GROUP, select_keys)),
 				printascii(key[1], func_to_key(SELECT_GOTO, select_keys)),
 				printascii(key[2], func_to_key(GLOBAL_SEARCH_SUBJECT_FORWARD, select_keys)),
-				printascii(key[3], func_to_key(SELECT_CATCHUP, select_keys)));
+				printascii(key[3], func_to_key(CATCHUP, select_keys)));
 			center_line(line, FALSE, buf);
 			snprintf(buf, bufs, _(txt_mini_select_2),
 				printascii(key[0], func_to_key(GLOBAL_LINE_DOWN, select_keys)),
@@ -561,7 +583,7 @@ show_mini_help(
 			center_line(line, FALSE, buf);
 			snprintf(buf, bufs, _(txt_mini_group_2),
 				printascii(key[0], func_to_key(GLOBAL_SEARCH_AUTHOR_FORWARD, group_keys)),
-				printascii(key[1], func_to_key(GROUP_CATCHUP, group_keys)),
+				printascii(key[1], func_to_key(CATCHUP, group_keys)),
 				printascii(key[2], func_to_key(GLOBAL_LINE_DOWN, group_keys)),
 				printascii(key[3], func_to_key(GLOBAL_LINE_UP, group_keys)),
 				printascii(key[4], func_to_key(GROUP_MARK_THREAD_READ, group_keys)),
@@ -586,7 +608,7 @@ show_mini_help(
 		case THREAD_LEVEL:
 			snprintf(buf, bufs, _(txt_mini_thread_1),
 				printascii(key[0], func_to_key(THREAD_READ_NEXT_ARTICLE_OR_THREAD, thread_keys)),
-				printascii(key[1], func_to_key(THREAD_CATCHUP, thread_keys)),
+				printascii(key[1], func_to_key(CATCHUP, thread_keys)),
 				printascii(key[2], func_to_key(THREAD_TOGGLE_SUBJECT_DISPLAY, thread_keys)));
 			center_line(line, FALSE, buf);
 			snprintf(buf, bufs, _(txt_mini_thread_2),
@@ -595,7 +617,7 @@ show_mini_help(
 				printascii(key[2], func_to_key(GLOBAL_LINE_UP, thread_keys)),
 				printascii(key[3], func_to_key(GLOBAL_QUIT, thread_keys)),
 				printascii(key[4], func_to_key(THREAD_TAG, thread_keys)),
-				printascii(key[5], func_to_key(THREAD_MARK_ARTICLE_UNREAD, thread_keys)));
+				printascii(key[5], func_to_key(MARK_ARTICLE_UNREAD, thread_keys)));
 			center_line(line + 1, FALSE, buf);
 			break;
 
@@ -608,7 +630,7 @@ show_mini_help(
 			snprintf(buf, bufs, _(txt_mini_page_2),
 				printascii(key[0], func_to_key(GLOBAL_SEARCH_AUTHOR_FORWARD, page_keys)),
 				printascii(key[1], func_to_key(GLOBAL_SEARCH_BODY, page_keys)),
-				printascii(key[2], func_to_key(PAGE_CATCHUP, page_keys)),
+				printascii(key[2], func_to_key(CATCHUP, page_keys)),
 				printascii(key[3], func_to_key(PAGE_FOLLOWUP_QUOTE, page_keys)),
 				printascii(key[4], func_to_key(PAGE_MARK_THREAD_READ, page_keys)));
 			center_line(line + 1, FALSE, buf);
