@@ -3,10 +3,10 @@
  *  Module    : inews.c
  *  Author    : I. Lea
  *  Created   : 1992-03-17
- *  Updated   : 2005-02-12
+ *  Updated   : 2006-02-15
  *  Notes     : NNTP built in version of inews
  *
- * Copyright (c) 1991-2005 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2007 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -58,19 +58,9 @@
 #endif /* NNTP_INEWS && !FORGERY */
 
 #if 0
-#	ifdef VMS
-#		ifdef MULTINET
-#			define netwrite	socket_write
-#			include "multinet_root:[multinet.include]netdb.h"
-#		else
-#			define netwrite	write
-#			include <netdb.h>
-#		endif /* MULTINET */
-#	else
-#		ifdef HAVE_NETDB_H
-#			include <netdb.h>
-#		endif /* HAVE_NETDB_H */
-#	endif /* VMS */
+#	ifdef HAVE_NETDB_H
+#		include <netdb.h>
+#	endif /* HAVE_NETDB_H */
 
 #	ifdef HAVE_SYS_SOCKET_H
 #		include <sys/socket.h>
