@@ -3,10 +3,10 @@
  *  Module    : init.c
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2005-01-30
+ *  Updated   : 2006-06-28
  *  Notes     :
  *
- * Copyright (c) 1991-2005 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2007 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -44,9 +44,6 @@
 #ifndef included_trace_h
 #	include "trace.h"
 #endif /* !included_trace_h */
-#ifndef KEYMAP_H
-#	include "keymap.h"
-#endif /* !KEYMAP_H */
 #ifndef VERSION_H
 #	include "version.h"
 #endif /* !VERSION_H */
@@ -69,7 +66,7 @@ static int read_site_config(void);
 char **news_headers_to_display_array;	/* array of which headers to display */
 char **news_headers_to_not_display_array;	/* array of which headers to not display */
 char active_times_file[PATH_LEN];
-char article[PATH_LEN];			/* ~/TIN_ARTICLE_NAME file */
+char article_name[PATH_LEN];			/* ~/TIN_ARTICLE_NAME file */
 char bug_nntpserver1[PATH_LEN];		/* welcome message of NNTP server used */
 char bug_nntpserver2[PATH_LEN];		/* welcome message of NNTP server used */
 char cmdline_nntpserver[PATH_LEN];
@@ -120,10 +117,6 @@ char userid[PATH_LEN];
 	char novrootdir[PATH_LEN];		/* root directory of nov index files */
 #endif /* !NNTP_ONLY */
 
-#ifdef VMS
-	char rcdir_asfile[PATH_LEN];	/* rcdir expressed as dev:[dir]tin.dir, for stat() */
-#endif /* VMS */
-
 t_function last_search;	/* for repeated search */
 int hist_last[HIST_MAXNUM + 1];
 int hist_pos[HIST_MAXNUM + 1];
@@ -183,6 +176,7 @@ char *input_history[HIST_MAXNUM + 1][HIST_SIZE + 1];
 struct regex_cache
 		strip_re_regex, strip_was_regex,
 		uubegin_regex, uubody_regex,
+		verbatim_begin_regex, verbatim_end_regex,
 		url_regex, mail_regex, news_regex,
 		shar_regex,
 		slashes_regex, stars_regex, underscores_regex, strokes_regex
@@ -267,6 +261,8 @@ struct t_config tinrc = {
 	"",		/* sigfile */
 	"",		/* strip_re_regex */
 	"",		/* strip_was_regex */
+	"",		/* verbatim_begin_regex */
+	"",		/* verbatim_end_regex */
 	"",		/* savedir */
 	"",		/* spamtrap_warning_addresses */
 	DEFAULT_URL_HANDLER,	/* url_handler */
@@ -278,6 +274,7 @@ struct t_config tinrc = {
 	'a',		/* default_save_mode */
 	0,		/* getart_limit */
 	2,		/* recent_time */
+	GOTO_NEXT_UNREAD_TAB,		/* goto_next_unread */
 	32,		/* groupname_max_length */
 	UUE_NO,	/* hide_uue */
 	KILL_UNREAD,		/* kill_level */
@@ -291,6 +288,7 @@ struct t_config tinrc = {
 	SORT_THREADS_BY_SCORE_DESCEND,		/* sort_threads_type */
 	BOGUS_SHOW,		/* strip_bogus */
 	THREAD_BOTH,		/* thread_articles */
+	THREAD_PERC_DEFAULT,	/* thread_perc */
 	THREAD_SCORE_MAX,	/* thread_score */
 	0,		/* Default to wildmat, not regex */
 	-50,		/* score_limit_kill */
@@ -364,7 +362,6 @@ struct t_config tinrc = {
 	FALSE,		/* mail_8bit_header */
 	FALSE,		/* mark_ignore_tags */
 	TRUE,		/* mark_saved_read */
-	TRUE,		/* pgdn_goto_next */
 	TRUE,		/* pos_first_unread */
 	FALSE,		/* post_8bit_header */
 	TRUE,		/* post_process_view */
@@ -375,13 +372,12 @@ struct t_config tinrc = {
 	FALSE,		/* prompt_followupto */
 	QUOTE_COMPRESS|QUOTE_EMPTY,	/* quote_style */
 	TRUE,		/* show_description */
-	1,		/* show_infos */
+	SHOW_INFO_LINES,		/* show_info */
 	TRUE,		/* show_only_unread_arts */
 	FALSE,		/* show_only_unread_groups */
 	TRUE,		/* show_signatures */
 	TRUE,		/* sigdashes */
 	TRUE,		/* signature_repost */
-	FALSE,		/* space_goto_next_unread */
 #ifdef M_UNIX
 	TRUE,		/* start_editor_offset */
 #else
@@ -389,7 +385,6 @@ struct t_config tinrc = {
 #endif /* M_UNIX */
 	TRUE,		/* strip_blanks */
 	FALSE,		/* strip_newsrc */
-	TRUE,		/* tab_goto_next_unread */
 	FALSE,		/* tex2iso_conv */
 	TRUE,		/* thread_catchup_on_exit */
 	TRUE,		/* unlink_article */
@@ -419,6 +414,44 @@ struct t_config tinrc = {
 #endif /* HAVE_LIBICUUC && MULTIBYTE_ABLE && HAVE_UNICODE_UBIDI_H && !NO_LOCALE */
 };
 
+struct t_capabilities nntp_caps = {
+	0, /* type (none, LIST EXTENSIONS, CAPABILITIES) */
+	0, /* CAPABILITIES version */
+	FALSE, /* MODE-READER: "MODE READER" */
+	FALSE, /* READER: "ARTICLE", "BODY" */
+	FALSE, /* POST */
+	FALSE, /* LIST: "LIST ACTIVE" */
+	FALSE, /* LIST: "LIST ACTIVE.TIMES" */
+	FALSE, /* LIST: "LIST DISTRIB.PATS" */
+	FALSE, /* LIST: "LIST HEADERS" */
+	FALSE, /* LIST: "LIST NEWSGROUPS" */
+	FALSE, /* LIST: "LIST OVERVIEW.FMT" */
+	FALSE, /* LIST: "LIST MOTD" */
+	FALSE, /* LIST: "LIST SUBSCRIPTIONS" */
+	FALSE, /* LIST: "LIST DISTRIBUTIONS" */
+	FALSE, /* LIST: "LIST MODERATORS" */
+	FALSE, /* XPAT */
+	FALSE, /* HDR: "HDR", "LIST HEADERS" */
+	NULL, /* [X]HDR */
+	FALSE, /* OVER: "OVER", "LIST OVERVIEW.FMT" */
+	FALSE, /* OVER: "OVER mid" */
+	NULL, /* [X]OVER */
+	FALSE, /* NEWNEWS */
+	NULL, /* IMPLEMENTATION */
+	FALSE, /* STARTTLS */
+	FALSE, /* AUTHINFO USER/PASS */
+	FALSE, /* AUTHINFO SASL */
+#if 0
+	FALSE, /* SASL CRAM-MD5 */
+	FALSE, /* SASL DIGEST-MD5 */
+	FALSE, /* SASL PLAIN */
+	FALSE, /* SASL GSSAPI */
+	FALSE, /* SASL EXTERNAL */
+	FALSE, /* STREAMING: "MODE STREAM", "CHECK", "TAKETHIS" */
+	FALSE /* IHAVE */
+#endif /* 0 */
+};
+
 static mode_t real_umask;
 
 #ifdef HAVE_COLOR
@@ -502,9 +535,9 @@ void
 init_selfinfo(
 	void)
 {
+	FILE *fp;
 	char *ptr;
 	const char *cptr;
-	FILE *fp;
 	struct stat sb;
 	struct passwd *myentry;
 
@@ -542,26 +575,13 @@ init_selfinfo(
 	real_umask = umask(0);
 	(void) umask(real_umask);
 
-#ifndef VMS
 	if ((myentry = getpwuid(getuid())) == NULL) {
 		error_message(_(txt_error_passwd_missing));
 		giveup();
 	}
-#else
-	if (((ptr = getlogin()) != NULL) && strlen(ptr))
-		myentry = getpwnam(ptr);
-	else {
-		error_message(_(txt_error_passwd_missing));
-		giveup();
-	}
-#endif /* !VMS */
 
 	strcpy(userid, myentry->pw_name);
 
-#ifdef VMS
-	lower(userid);
-#endif /* VMS */
-
 	if (((ptr = getenv("TIN_HOMEDIR")) != NULL) && strlen(ptr)) {
 		my_strncpy(homedir, ptr, sizeof(homedir) - 1);
 	} else if (((ptr = getenv("HOME")) != NULL) && strlen(ptr)) {
@@ -575,15 +595,7 @@ init_selfinfo(
 	created_rcdir = FALSE;
 	dangerous_signal_exit = FALSE;
 	disable_gnksa_domain_check = FALSE;
-#ifdef MAC_OS_X	/* usualy they don't have a valid FQDN */
-	/*
-	 * TODO: check if gnksa_check_domain(get_fqdn()) returns ok
-	 *       and if it does, don't disable Sender
-	 */
-	disable_sender = TRUE;
-#else
-	disable_sender = FALSE;
-#endif /* MAC_OS_X */
+	disable_sender = FALSE;	/* we set force_no_post=TRUE later on if we don't have a valid FQDN */
 	filtered_articles = FALSE;
 	iso2asc_supported = atoi(get_val("ISO2ASC", DEFAULT_ISO2ASC));
 	if (iso2asc_supported > NUM_ISO_TABLES || iso2asc_supported < 0) /* TODO: issue a warning here? */
@@ -732,16 +744,8 @@ init_selfinfo(
 	joinpath(global_config_file, libdir, CONFIG_FILE);
 #endif /* TIN_DEFAULTS_DIR */
 
-#ifdef VMS
-	joindir(rcdir, homedir, RCDIR); /* we're naming a directory here */
-	joinpath(rcdir_asfile, homedir, RCDIR);	/* for stat() */
-	strcat(rcdir_asfile, ".DIR");
-	if (stat(rcdir_asfile, &sb) == -1)
-#else
 	joinpath(rcdir, homedir, RCDIR);
-	if (stat(rcdir, &sb) == -1)
-#endif /* VMS */
-	{
+	if (stat(rcdir, &sb) == -1) {
 		created_rcdir = TRUE;
 		my_mkdir(rcdir, (mode_t) (S_IRWXU));
 	}
@@ -751,23 +755,23 @@ init_selfinfo(
 	strcpy(tinrc.printer, DEFAULT_PRINTER);
 #endif /* !DISABLE_PRINTING */
 	strcpy(tinrc.inews_prog, PATH_INEWS);
-	joinpath(article, homedir, TIN_ARTICLE_NAME);
+	joinpath(article_name, homedir, TIN_ARTICLE_NAME);
 #ifdef APPEND_PID
-	snprintf(article + strlen(article), sizeof(article) - strlen(article), ".%d", (int) process_id);
+	snprintf(article_name + strlen(article_name), sizeof(article_name) - strlen(article_name), ".%d", (int) process_id);
 #endif /* APPEND_PID */
 	joinpath(dead_article, homedir, "dead.article");
 	joinpath(dead_articles, homedir, "dead.articles");
-	JOINPATH(tinrc.maildir, homedir, DEFAULT_MAILDIR);
-	JOINPATH(tinrc.savedir, homedir, DEFAULT_SAVEDIR);
+	joinpath(tinrc.maildir, homedir, DEFAULT_MAILDIR);
+	joinpath(tinrc.savedir, homedir, DEFAULT_SAVEDIR);
 	joinpath(tinrc.sigfile, homedir, ".Sig");
 	joinpath(default_signature, homedir, ".signature");
 
 	if (!index_newsdir[0])
-		JOINPATH(index_newsdir, get_val("TIN_INDEX_NEWSDIR", rcdir), INDEX_NEWSDIR);
-	JOINPATH(index_maildir, get_val("TIN_INDEX_MAILDIR", rcdir), INDEX_MAILDIR);
+		joinpath(index_newsdir, get_val("TIN_INDEX_NEWSDIR", rcdir), INDEX_NEWSDIR);
+	joinpath(index_maildir, get_val("TIN_INDEX_MAILDIR", rcdir), INDEX_MAILDIR);
 	if (stat(index_maildir, &sb) == -1)
 		my_mkdir(index_maildir, (mode_t) S_IRWXU);
-	JOINPATH(index_savedir, get_val("TIN_INDEX_SAVEDIR", rcdir), INDEX_SAVEDIR);
+	joinpath(index_savedir, get_val("TIN_INDEX_SAVEDIR", rcdir), INDEX_SAVEDIR);
 	if (stat(index_savedir, &sb) == -1)
 		my_mkdir(index_savedir, (mode_t) S_IRWXU);
 	joinpath(local_attributes_file, rcdir, ATTRIBUTES_FILE);
@@ -775,15 +779,10 @@ init_selfinfo(
 	joinpath(filter_file, rcdir, FILTER_FILE);
 	joinpath(local_input_history_file, rcdir, INPUT_HISTORY_FILE);
 	joinpath(local_newsrctable_file, rcdir, NEWSRCTABLE_FILE);
-	joinpath(local_newsgroups_file, rcdir, NEWSGROUPS_FILE);
 #ifdef HAVE_MH_MAIL_HANDLING
 	joinpath(mail_active_file, rcdir, ACTIVE_MAIL_FILE);
 #endif /* HAVE_MH_MAIL_HANDLING */
-#ifdef VMS
-	joinpath(mailbox, DEFAULT_MAILBOX, "MAIL.TXT");
-#else
 	joinpath(mailbox, DEFAULT_MAILBOX, userid);
-#endif /* VMS */
 #ifdef HAVE_MH_MAIL_HANDLING
 	joinpath(mailgroups_file, rcdir, MAILGROUPS_FILE);
 #endif /* HAVE_MH_MAIL_HANDLING */
@@ -969,6 +968,13 @@ postinit_regexp(
 		STRCPY(tinrc.underscores_regex, DEFAULT_UNDERSCORES_REGEX);
 	compile_regex(tinrc.underscores_regex, &underscores_regex, PCRE_CASELESS);
 
+	if (!strlen(tinrc.verbatim_begin_regex))
+		STRCPY(tinrc.verbatim_begin_regex, DEFAULT_VERBATIM_BEGIN_REGEX);
+	compile_regex(tinrc.verbatim_begin_regex, &verbatim_begin_regex, PCRE_ANCHORED);
+	if (!strlen(tinrc.verbatim_end_regex))
+		STRCPY(tinrc.verbatim_end_regex, DEFAULT_VERBATIM_END_REGEX);
+	compile_regex(tinrc.verbatim_end_regex, &verbatim_end_regex, PCRE_ANCHORED);
+
 	compile_regex(UUBEGIN_REGEX, &uubegin_regex, PCRE_ANCHORED);
 	compile_regex(UUBODY_REGEX, &uubody_regex, PCRE_ANCHORED);
 
