@@ -3,10 +3,10 @@
  *  Module    : mail.c
  *  Author    : I. Lea
  *  Created   : 1992-10-02
- *  Updated   : 2005-08-14
+ *  Updated   : 2006-02-15
  *  Notes     : Mail handling routines for creating pseudo newsgroups
  *
- * Copyright (c) 1992-2006 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1992-2007 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -301,7 +301,7 @@ read_newsgroups_file(
 			struct stat buf;
 
 			if (stat(local_newsgroups_file, &buf) || !read_local_newsgroups_file)
-				fp_save = fopen(local_newsgroups_file, "w" FOPEN_OPTS);
+				fp_save = fopen(local_newsgroups_file, "w");
 		}
 
 		read_groups_descriptions(fp, fp_save);
@@ -369,7 +369,7 @@ read_groups_descriptions(
 			space = strlen(ptr) + 1;
 			groupname = my_malloc(space);
 		} else {
-			while (strlen(ptr) > space) { /* realloc needed? */
+			while (space < strlen(ptr) + 1) { /* realloc needed? */
 				space <<= 1; /* double size */
 				groupname = my_realloc(groupname, space);
 			}
@@ -397,10 +397,8 @@ read_groups_descriptions(
 			r_len = strlen(r);
 			/*
 			 * Protect against invalid character sequences.
-			 *
-			 * TODO: change US-ASCII to UTF-8 when NNTP draft becomes RFC
 			 */
-			process_charsets(&r, &r_len, "US-ASCII", tinrc.mm_local_charset, FALSE);
+			process_charsets(&r, &r_len, "UTF-8", tinrc.mm_local_charset, FALSE);
 			group->description = convert_to_printable(r);
 		}
 
