@@ -3,10 +3,10 @@
  *  Module    : memory.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2005-02-25
+ *  Updated   : 2006-03-11
  *  Notes     :
  *
- * Copyright (c) 1991-2005 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2007 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -38,9 +38,7 @@
 #ifndef TIN_H
 #	include "tin.h"
 #endif /* !TIN_H */
-#ifndef RFC2046_H
-#	include "rfc2046.h"
-#endif /* !RFC2046_H */
+
 
 /*
  * Dynamic arrays maximum (initialized in init_alloc()) & current sizes
@@ -228,6 +226,10 @@ free_all_arrays(
 	FreeIfNeeded(uubegin_regex.extra);
 	FreeIfNeeded(uubody_regex.re);
 	FreeIfNeeded(uubody_regex.extra);
+	FreeIfNeeded(verbatim_begin_regex.re);
+	FreeIfNeeded(verbatim_begin_regex.extra);
+	FreeIfNeeded(verbatim_end_regex.re);
+	FreeIfNeeded(verbatim_end_regex.extra);
 	FreeIfNeeded(url_regex.re);
 	FreeIfNeeded(url_regex.extra);
 	FreeIfNeeded(mail_regex.re);
@@ -254,6 +256,8 @@ free_all_arrays(
 		FreeAndNull(newnews);
 	}
 
+	FreeAndNull(nntp_caps.implementation);
+
 	tin_fgets(NULL, FALSE);
 }
 
