@@ -3,7 +3,7 @@
  *  Module    : misc.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2005-08-14
+ *  Updated   : 2006-04-06
  *  Notes     :
  *
  * Copyright (c) 1991-2006 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
@@ -648,12 +648,6 @@ tin_done(
 	}
 #endif /* USE_DBMALLOC */
 
-#ifdef VMS
-	if (!ret)
-		ret = 1;
-	vms_close_stdin(); /* free resources used by ReadCh */
-#endif /* VMS */
-
 	exit(ret);
 }
 
@@ -745,30 +739,6 @@ rename_file(
 #endif /* M_UNIX */
 
 
-#ifdef VMS
-void
-rename_file(
-	char *old_filename,
-	char *new_filename)
-{
-	char new_filename_vms[1024];
-
-	if (!strchr(strchr(new_filename, ']') ? strchr(new_filename, ']') : new_filename, '.')) {
-		/* without final dot the new filename is not as tin expects */
-		if (strlen(new_filename) >= sizeof(new_filename_vms)) {
-			perror_message("length of %s is too large", new_filename);
-			return;
-		}
-		strcpy(new_filename_vms, new_filename);
-		strcat(new_filename_vms, ".");
-		new_filename = &new_filename_vms[0];
-	}
-
-	if (rename(old_filename, new_filename))
-		perror_message(_(txt_rename_error), old_filename, new_filename);
-}
-#endif /* VMS */
-
 
 /*
  * Note that we exit screen/curses mode when invoking
@@ -790,13 +760,9 @@ invoke_cmd(
 
 	TRACE(("called system(%s)", _nc_visbuf(nam)));
 	ret = system(nam);
-#ifdef VMS
-	system_status = 0;
-#else
-#	ifndef USE_SYSTEM_STATUS
+#ifndef USE_SYSTEM_STATUS
 	system_status = (ret >= 0 && WIFEXITED(ret)) ? WEXITSTATUS(ret) : 0;
-#	endif /* !USE_SYSTEM_STATUS */
-#endif /* VMS */
+#endif /* !USE_SYSTEM_STATUS */
 	TRACE(("return %d (%d)", ret, system_status));
 
 	set_signal_catcher(TRUE);
@@ -810,11 +776,7 @@ invoke_cmd(
 	return TRUE;
 #else
 
-#	ifdef VMS
-		success = (ret != 0);
-#	else
-		success = (ret == 0);
-#	endif /* VMS */
+	success = (ret == 0);
 
 	if (!success || system_status != 0)
 		error_message(_(txt_command_failed), nam);
@@ -867,9 +829,6 @@ base_name(
 	char *file)				/* baz */
 {
 	size_t i;
-#ifdef VMS
-	char *cp;
-#endif /* VMS */
 
 	strcpy(file, fullpath);
 
@@ -879,10 +838,6 @@ base_name(
 			break;
 		}
 	}
-#ifdef VMS
-	if ((cp = strrchr(file, '.')) != 0)
-		*cp = '\0';
-#endif /* VMS */
 }
 
 
@@ -912,7 +867,7 @@ dir_name(
  *
  * TODO: why not cache the mailbox_name?
  */
-#define MAILDIR_NEW	"/new"
+#define MAILDIR_NEW	"new"
 t_bool
 mail_check(
 	void)
@@ -928,12 +883,9 @@ mail_check(
 			char *maildir_box;
 			struct dirent *dp;
 
-			maildir_box = my_malloc(strlen(mailbox_name) + strlen(MAILDIR_NEW) + 1);
-#ifdef VMS
-			joindir(maildir_box, mailbox_name, MAILDIR_NEW);
-#else
+			maildir_box = my_malloc(strlen(mailbox_name) + strlen(MAILDIR_NEW) + 2);
 			joinpath(maildir_box, mailbox_name, MAILDIR_NEW);
-#endif /* VMS */
+
 			if (!(dirp = opendir(maildir_box))) {
 				free(maildir_box);
 				return FALSE;
@@ -1148,7 +1100,7 @@ create_index_lock_file(
 /*
  * strfquote() - produce formatted quote string
  *   %A  Articles Email address
- *   %D  Articles Date
+ *   %D  Articles Date (uses tinrc.date_format)
  *   %F  Articles Address+Name
  *   %G  Groupname of Article
  *   %M  Articles MessageId
@@ -1243,8 +1195,10 @@ strfquote(
 					}
 					break;
 
-				case 'D':	/* Articles Date */
-					STRCPY(tbuf, BlankIfNull(pgart.hdr.date));
+				case 'D':	/* Articles Date (reformated as specified in tinrc.date_format) */
+					if (!my_strftime(tbuf, LEN - 1, tinrc.date_format, localtime(&arts[this_resp].date))) {
+						STRCPY(tbuf, BlankIfNull(pgart.hdr.date));
+					}
 					break;
 
 				case 'F':	/* Articles Address+Name */
@@ -1493,12 +1447,7 @@ _strfpath(
 		/*
 		 * If just a normal part of the pathname copy it
 		 */
-#ifdef VMS
-		if (!strchr("~=+%", *format))
-#else
-		if (!strchr("~$=+%", *format))
-#endif /* VMS */
-		{
+		if (!strchr("~$=+%", *format)) {
 			*str++ = *format;
 			continue;
 		}
@@ -1529,7 +1478,6 @@ _strfpath(
 					return 0;
 				break;
 
-#ifndef VMS
 			case '$':	/* Read the envvar and use its value */
 				i = 0;
 				format++;
@@ -1567,7 +1515,6 @@ _strfpath(
 					return 0;
 				}
 				break;
-#endif /* !VMS */
 
 			case '=':
 				/*
@@ -1614,7 +1561,7 @@ _strfpath(
 #else
 						my_strncpy(tmp, group->name, 14);
 #endif /* HAVE_LONG_FILE_NAMES */
-						JOINPATH(tbuf, buf, tmp);	/* Add the group name */
+						joinpath(tbuf, buf, tmp);	/* Add the group name */
 						joinpath(tmp, tbuf, "");
 						if ((str = strfpath_cp(str, tmp, endp)) == NULL)
 							return 0;
@@ -2010,9 +1957,6 @@ make_group_path(
 	const char *name,
 	char *path)
 {
-#ifdef VMS
-	sprintf(path, "[%s]", name);
-#else
 	while (*name) {
 		*path = ((*name == '.') ? '/' : *name);
 		name++;
@@ -2020,7 +1964,6 @@ make_group_path(
 	}
 	*path++ = '/';
 	*path = '\0';
-#endif /* VMS */
 }
 
 
