@@ -3,10 +3,10 @@
  *  Module    : newsrc.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2004-11-16
+ *  Updated   : 2006-02-15
  *  Notes     : ArtCount = (ArtMax - ArtMin) + 1  [could have holes]
  *
- * Copyright (c) 1991-2005 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2006 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -91,7 +91,7 @@ read_newsrc(
 		selmenu.max = skip_newgroups();
 
 	/*
-	 * make a .newsrc if one doesn't exist & auto subscribe to set groups
+	 * make a .newsrc if none exist & auto subscribe to set groups
 	 */
 	if (stat(newsrc_file, &statbuf) == -1) {
 		if (!create_newsrc(newsrc_file))
@@ -214,7 +214,7 @@ write_newsrc(
 		return 0L; /* newsrc is empty */
 	}
 
-	if ((fp_op = fopen(newnewsrc, "w" FOPEN_OPTS)) != NULL) {
+	if ((fp_op = fopen(newnewsrc, "w")) != NULL) {
 		if (newsrc_mode)
 			fchmod(fileno(fp_op), newsrc_mode);
 
@@ -274,24 +274,22 @@ create_newsrc(
 /*
  * Get a list of default groups to subscribe to
  */
-/* TODO: fixme/checkme
- *      - logic seems to be wrong, NNTP_ABLE && read_saved_news
- *        looks for a local subscriptions_file, but read_saved_news doesn't
- *        require a local server... (a missing subscriptions_file doesn't
- *        cause any trouble, we just have to bother with the read_saved_news
- *        and a existing local subscriptions_file file case).
- *        open_newgroups_fp() uses the same logic.
- */
 static FILE *
 open_subscription_fp(
 	void)
 {
+	if (!read_saved_news) {
 #ifdef NNTP_ABLE
-	if (read_news_via_nntp && !read_saved_news)
-		return (nntp_command("LIST SUBSCRIPTIONS", OK_GROUPS, NULL, 0));
-	else
+		if (read_news_via_nntp) {
+			/* if (nntp_caps.type = 2 && !nntp_caps.list_subscriptions)
+				return NULL;
+			else */
+				return (nntp_command("LIST SUBSCRIPTIONS", OK_GROUPS, NULL, 0));
+		} else
 #endif /* NNTP_ABLE */
-		return (fopen(subscriptions_file, "r"));
+			return (fopen(subscriptions_file, "r"));
+	} else
+		return NULL;
 }
 
 
@@ -318,7 +316,7 @@ auto_subscribe_groups(
 	if (!batch_mode)
 		wait_message(0, _(txt_autosubscribing_groups));
 
-	if ((fp_newsrc = fopen(newsrc_file, "w" FOPEN_OPTS)) == NULL)
+	if ((fp_newsrc = fopen(newsrc_file, "w")) == NULL)
 		return;
 
 	if (newsrc_mode)
@@ -360,7 +358,7 @@ backup_newsrc(
 	{
 		STRCPY(filebuf, quote_space_to_dash(nntp_server));
 	}
-	JOINPATH(dirbuf, rcdir, filebuf);
+	joinpath(dirbuf, rcdir, filebuf);
 	joinpath(filebuf, dirbuf, OLDNEWSRC_FILE);
 
 	if (-1 == stat(dirbuf, &statbuf)) {
@@ -512,7 +510,7 @@ subscribe(
 	if (no_write)
 		return;
 
-	if ((newfp = fopen(newnewsrc, "w" FOPEN_OPTS)) == NULL)
+	if ((newfp = fopen(newnewsrc, "w")) == NULL)
 		return;
 
 	if (newsrc_mode)
@@ -569,7 +567,7 @@ reset_newsrc(
 	int sub;
 	long i;
 
-	if (!no_write && (newfp = fopen(newnewsrc, "w" FOPEN_OPTS)) != NULL) {
+	if (!no_write && (newfp = fopen(newnewsrc, "w")) != NULL) {
 		if (newsrc_mode)
 			fchmod(fileno(newfp), newsrc_mode);
 
@@ -608,7 +606,7 @@ delete_group(
 	if (no_write)
 		return;
 
-	if ((newfp = fopen(newnewsrc, "w" FOPEN_OPTS)) != NULL) {
+	if ((newfp = fopen(newnewsrc, "w")) != NULL) {
 		if (newsrc_mode)
 			fchmod(fileno(newfp), newsrc_mode);
 
@@ -1125,7 +1123,7 @@ pos_group_in_newsrc(
 	if ((fp_in = fopen(newsrc, "r")) == NULL)
 		goto rewrite_group_done;
 
-	if ((fp_out = fopen(newnewsrc, "w" FOPEN_OPTS)) == NULL)
+	if ((fp_out = fopen(newnewsrc, "w")) == NULL)
 		goto rewrite_group_done;
 
 	newnewsrc_created = TRUE;
@@ -1133,26 +1131,18 @@ pos_group_in_newsrc(
 	if (newsrc_mode)
 		fchmod(fileno(fp_out), newsrc_mode);
 
-#ifdef VMS
-	joinpath(buf, TMPDIR, "subrc");
-	snprintf(sub, sizeof(sub), "%s.%d", buf, (int) process_id);
-
-	joinpath(buf, TMPDIR, "unsubrc");
-	snprintf(unsub, sizeof(unsub), "%s.%d", buf, (int) process_id);
-#else
 	joinpath(buf, TMPDIR, ".subrc");
 	snprintf(sub, sizeof(sub), "%s.%d", buf, (int) process_id);
 
 	joinpath(buf, TMPDIR, ".unsubrc");
 	snprintf(unsub, sizeof(unsub), "%s.%d", buf, (int) process_id);
-#endif /* !VMS */
 
-	if ((fp_sub = fopen(sub, "w" FOPEN_OPTS)) == NULL)
+	if ((fp_sub = fopen(sub, "w")) == NULL)
 		goto rewrite_group_done;
 
 	sub_created = TRUE;
 
-	if ((fp_unsub = fopen(unsub, "w" FOPEN_OPTS)) == NULL)
+	if ((fp_unsub = fopen(unsub, "w")) == NULL)
 		goto rewrite_group_done;
 
 	unsub_created = TRUE;
@@ -1556,6 +1546,7 @@ set_default_bitmap(
 
 /* TEST harness */
 #ifdef DEBUG_NEWSRC
+#	if 0
 static void set_bitmap_range_read(struct t_newsrc *my_newsrc, long beg, long end);
 static void set_bitmap_range_unread(struct t_newsrc *my_newsrc, long beg, long end);
 
@@ -1690,4 +1681,5 @@ my_newsrc->xmin, my_newsrc->xmax, beg, end, offset, length);
 		}
 	}
 }
+#	endif /* 0 */
 #endif /* DEBUG_NEWSRC */
