@@ -3,7 +3,7 @@
  *  Module    : nntplib.c
  *  Author    : S. Barber & I. Lea
  *  Created   : 1991-01-12
- *  Updated   : 2005-11-17
+ *  Updated   : 2007-01-09
  *  Notes     : NNTP client routines taken from clientlib.c 1.5.11 (1991-02-10)
  *  Copyright : (c) Copyright 1991-99 by Stan Barber & Iain Lea
  *              Permission is hereby granted to copy, reproduce, redistribute
@@ -25,10 +25,6 @@
 #	include "tnntp.h"
 #endif /* !TNNTP_H */
 
-#ifdef VMS /* M.St. 15.01.98 */
-#	undef VMS
-#endif /* VMS */
-
 char *nntp_server = NULL;
 #ifdef NO_POSTING
 	t_bool can_post = FALSE;
@@ -125,14 +121,17 @@ getserverbyfile(
 	static char *old_env = NULL;
 #	endif /* !HAVE_SETENV && HAVE_PUTENV */
 #endif /* NNTP_ABLE */
+
 	if (!read_news_via_nntp) {
 		STRCPY(buf, "local");	/* what if a server is named "local"? */
 		return buf;
 	}
+
 	if (read_saved_news) {
 		STRCPY(buf, "reading saved news");
 		return buf;
 	}
+
 #ifdef NNTP_ABLE
 	if (cmdline_nntpserver[0] != '\0') {
 		get_nntpserver(buf, cmdline_nntpserver);
@@ -224,9 +223,7 @@ server_init(
 	char temp[256];
 	char *service = strncpy(temp, cservice, sizeof(temp) - 1); /* ...calls non-const funcs */
 #	endif /* !INET6 */
-#	ifndef VMS
 	int sockt_rd, sockt_wr;
-#	endif /* !VMS */
 
 #	ifdef DECNET
 	char *cp;
@@ -249,7 +246,6 @@ server_init(
 	if (sockt_rd < 0)
 		return sockt_rd;
 
-#	ifndef VMS
 	/*
 	 * Now we'll make file pointers (i.e., buffered I/O) out of
 	 * the socket file descriptor. Note that we can't just
@@ -267,23 +263,20 @@ server_init(
 		return -errno;
 	}
 
-#		ifdef TLI /* Transport Level Interface */
+#	ifdef TLI /* Transport Level Interface */
 	if (t_sync(sockt_rd) < 0) {	/* Sync up new fd with TLI */
 		t_error("server_init: t_sync()");
 		nntp_rd_fp = NULL;
 		return -EPROTO;
 	}
-#		else
+#	else
 	if ((nntp_wr_fp = (TCP *) s_fdopen(sockt_wr, "w")) == NULL) {
 		perror("server_init: fdopen() #2");
 		nntp_rd_fp = NULL;
 		return -errno;
 	}
-#		endif /* TLI */
+#	endif /* TLI */
 
-#	else
-	sockt_wr = sockt_rd;
-#	endif /* !VMS */
 
 	last_put[0] = '\0';		/* no retries in get_respcode */
 	/*
@@ -363,7 +356,7 @@ get_tcp_socket(
 			t_close(s);
 			return -EHOSTUNREACH;
 		}
-		memcpy((char *) &sock_in.sin_addr, hp->h_addr, hp->h_length);
+		memcpy((char *) &sock_in.sin_addr, hp->h_addr_list[0], hp->h_length);
 	}
 
 	/*
@@ -440,12 +433,12 @@ get_tcp_socket(
 #			endif /* HAVE_GETSERVBYNAME */
 
 	/* If not a raw ip address, try nameserver */
-	if (!isdigit((unsigned char) *machine) ||
+	if (!isdigit((unsigned char) *machine)
 #			ifdef HAVE_INET_ATON
-	    !inet_aton(machine, &defaddr)
+	    || !inet_aton(machine, &defaddr)
 #			else
 #				ifdef HAVE_INET_ADDR
-	    (long) (defaddr.s_addr = (long) inet_addr(machine)) == -1
+	    || (long) (defaddr.s_addr = (long) inet_addr(machine)) == -1
 #				endif /* HAVE_INET_ADDR */
 #			endif /* HAVE_INET_ATON */
 	    )
@@ -458,7 +451,7 @@ get_tcp_socket(
 #			ifdef h_addr
 		def.h_addr_list = alist;
 #			endif /* h_addr */
-		def.h_addr = (char *) &defaddr;
+		def.h_addr_list[0] = (char *) &defaddr;
 		def.h_length = sizeof(struct in_addr);
 		def.h_addrtype = AF_INET;
 		def.h_aliases = 0;
@@ -575,7 +568,7 @@ get_tcp_socket(
 
 	/* And then connect */
 
-	memcpy((char *) &sock_in.sin_addr, hp->h_addr, hp->h_length);
+	memcpy((char *) &sock_in.sin_addr, hp->h_addr_list[0], hp->h_length);
 
 	if (connect(s, (struct sockaddr *) &sock_in, sizeof(sock_in)) < 0) {
 		save_errno = errno;
@@ -749,16 +742,15 @@ get_dnet_socket(
 /*
  * u_put_server -- send data to the server. Do not flush output.
  */
-#ifndef VMS
-#	ifdef NNTP_ABLE
+#ifdef NNTP_ABLE
 void
 u_put_server(
 	const char *string)
 {
 	s_puts(string, nntp_wr_fp);
-#		ifdef DEBUG
+#	ifdef DEBUG
 	debug_nntp(">>>", string);
-#		endif /* DEBUG */
+#	endif /* DEBUG */
 }
 
 
@@ -784,9 +776,9 @@ put_server(
 		DEBUG_IO((stderr, "put_server(%s)\n", string));
 		s_puts(string, nntp_wr_fp);
 		s_puts("\r\n", nntp_wr_fp);
-#		ifdef DEBUG
+#	ifdef DEBUG
 		debug_nntp(">>>", string);
-#		endif /* DEBUG */
+#	endif /* DEBUG */
 		/*
 		 * remember the last command we wrote to be able to resend it after a
 		 * reconnect. reconnection is handled by get_server()
@@ -843,9 +835,9 @@ reconnect(
 			snprintf(last_put, sizeof(last_put), "GROUP %s", curr_group->name);
 			put_server(last_put);
 			s_gets(last_put, NNTP_STRLEN, nntp_rd_fp);
-#		ifdef DEBUG
+#	ifdef DEBUG
 			debug_nntp("<<<", last_put);
-#		endif /* DEBUG */
+#	endif /* DEBUG */
 			DEBUG_IO((stderr, _("Read (%s)\n"), last_put));
 		}
 		DEBUG_IO((stderr, _("Resend last command (%s)\n"), buf));
@@ -891,10 +883,10 @@ get_server(
 		if (quitting)						/* Don't bother to reconnect */
 			tin_done(NNTP_ERROR_EXIT);		/* And don't try to disconnect again! */
 
-#		ifdef DEBUG
+#	ifdef DEBUG
 		if (errno != 0 && errno != EINTR)	/* Will only confuse end users */
 			perror_message("get_server()");
-#		endif /* DEBUG */
+#	endif /* DEBUG */
 
 		/*
 		 * Reconnect only if command was not "QUIT" anyway (in which case a
@@ -947,8 +939,7 @@ close_server(
 	s_end();
 	nntp_wr_fp = nntp_rd_fp = NULL;
 }
-#	endif /* NNTP_ABLE */
-#endif /* !VMS */
+#endif /* NNTP_ABLE */
 
 
 #ifdef NNTP_ABLE
@@ -965,126 +956,139 @@ check_extensions(
 {
 	char *ptr;
 	int ret = 0;
-#	if 0 /* "CAPABILITIES" will replace "LIST EXTENSIONS" */
-	FILE *fp;
+#	if 1 /* "CAPABILITIES" replaces "LIST EXTENSIONS" */
+	char buf[NNTP_STRLEN];
 	char *d;
+	int i;
 
-	if ((fp = nntp_command("CAPABILITIES", INF_CAPABILITIES, NULL, 0)) != NULL) {
-		nntp_caps.type = CAPABILITIES;
-		while ((ptr = tin_fgets(fp, FALSE)) != NULL) {
+	buf[0] = '\0';
+	i = new_nntp_command("CAPABILITIES", INF_CAPABILITIES, buf, sizeof(buf));
+	switch (i) {
+		case INF_CAPABILITIES:
+			nntp_caps.type = CAPABILITIES;
+			while ((ptr = tin_fgets(FAKE_NNTP_FP, FALSE)) != NULL) {
 #		ifdef DEBUG
-			debug_nntp("<<<", ptr);
+				debug_nntp("<<<", ptr);
 #		endif /* DEBUG */
-			/* look for version number(s) */
-			if (!nntp_caps.version && nntp_caps.type == CAPABILITIES) {
-				if (!strcasecmp(ptr, "VERSION")) {
-					d = ptr + 7;
-					d = strpbrk(d, " \t");
-					while (d != NULL && (d + 1 < (ptr + strlen(ptr)))) {
-						d++;
-						nntp_caps.version = MAX(nntp_caps.version, (unsigned int) atoi(d));
+				/* look for version number(s) */
+				if (!nntp_caps.version && nntp_caps.type == CAPABILITIES) {
+					if (!strcasecmp(ptr, "VERSION")) {
+						d = ptr + 7;
 						d = strpbrk(d, " \t");
+						while (d != NULL && (d + 1 < (ptr + strlen(ptr)))) {
+							d++;
+							nntp_caps.version = MAX(nntp_caps.version, (unsigned int) atoi(d));
+							d = strpbrk(d, " \t");
+						}
 					}
 				}
-			}
-			/* we currently only support CAPABILITIES VERSION 2 */
-			if (nntp_caps.version == 2) {
-				/*
-				 * check for LIST variants - this code is untested
-				 */
-				if (!strcasecmp(ptr, "LIST")) {
-					d = ptr + 4;
-					d = strpbrk(d, " \t");
-					while (d != NULL && (d + 1 < (ptr + strlen(ptr)))) {
-						d++;
-						if (!strcasecmp(d, "ACTIVE.TIMES"))
-							nntp_caps.list_active_times = TRUE;
-						else if (!strcasecmp(d, "ACTIVE"))
-							nntp_caps.list_active_times = TRUE;
-						else if (!strcasecmp(d, "DISTRIB.PATS"))
-							nntp_caps.list_distrib_pats = TRUE;
-						else if (!strcasecmp(d, "DISTRIBUTIONS")) /* LIST DISTRIBUTIONS, "private" extension, RFC 2980 */
-							nntp_caps.list_distributions = TRUE;
-						else if (!strcasecmp(d, "HEADERS"))
-							nntp_caps.list_headers = TRUE; /* HDR requires LIST HEADERS, but not vice versa */
-						else if (!strcasecmp(d, "NEWSGROUPS"))
-							nntp_caps.list_newsgroups = TRUE;
-						else if (!strcasecmp(d, "OVERVIEW.FMT")) /* OVER requires OVERVIEW.FMT, but not vice versa */
-							nntp_caps.list_overview_fmt = TRUE;
-						else if (!strcasecmp(d, "MOTD")) /* "private" extension */
-							nntp_caps.list_motd = TRUE;
-						else if (!strcasecmp(d, "SUBSCRIPTIONS")) /* "private" extension, RFC 2980 */
-							nntp_caps.list_subscriptions = TRUE;
-						else if (!strcasecmp(d, "MODERATORS")) /* "private" extension */
-							nntp_caps.list_moderators = TRUE;
+				/* we currently only support CAPABILITIES VERSION 2 */
+				if (nntp_caps.version == 2) {
+					/*
+					 * check for LIST variants - this code is untested
+					 */
+					if (!strcasecmp(ptr, "LIST")) {
+						d = ptr + 4;
 						d = strpbrk(d, " \t");
-					}
-				} else if (!strcasecmp(ptr, "IMPLEMENTATION"))
-					nntp_caps.implementation = my_strdup(ptr + 14);
-				else if (!strcasecmp(ptr, "MODE-READER")) {
-					if (!nntp_caps.reader)
-						nntp_caps.mode_reader = TRUE;
-				} else if (!strcasecmp(ptr, "READER")) {
-					nntp_caps.reader = TRUE;
-					nntp_caps.mode_reader = FALSE;
-				} else if (!strcasecmp(d, "POST"))
-					nntp_caps.post = TRUE;
-				else if (!strcasecmp(ptr, "NEWNEWS"))
-					nntp_caps.newnews = TRUE;
-				else if (!strcasecmp(ptr, "XPAT")) /* extension, RFC 2980 */
-					nntp_caps.xpat = TRUE;
-				else if (!strcasecmp(ptr, "STARTTLS"))
-					nntp_caps.starttls = TRUE;
-				/*
-				 * NOTE: if we saw OVER, LIST OVERVIEW.FMT _must_ be implemented
-				 */
-				else if (!strcasecmp(ptr, &xover_cmds[1])) {
-					nntp_caps.over = TRUE;
-					nntp_caps.list_overview_fmt = TRUE;
-					nntp_caps.over_cmd = &xover_cmds[1];
-					d = ptr + strlen(&xover_cmds[1]);
-					d = strpbrk(d, " \t");
-					while (d != NULL && (d + 1 < (ptr + strlen(ptr)))) {
-						d++;
-						if (!strcasecmp(d, "MSGID"))
-							nntp_caps.over_msgid = TRUE;
+						while (d != NULL && (d + 1 < (ptr + strlen(ptr)))) {
+							d++;
+							if (!strcasecmp(d, "ACTIVE.TIMES"))
+								nntp_caps.list_active_times = TRUE;
+							else if (!strcasecmp(d, "ACTIVE"))
+								nntp_caps.list_active_times = TRUE;
+							else if (!strcasecmp(d, "DISTRIB.PATS"))
+								nntp_caps.list_distrib_pats = TRUE;
+							else if (!strcasecmp(d, "DISTRIBUTIONS")) /* LIST DISTRIBUTIONS, "private" extension, RFC 2980 */
+								nntp_caps.list_distributions = TRUE;
+							else if (!strcasecmp(d, "HEADERS"))
+								nntp_caps.list_headers = TRUE; /* HDR requires LIST HEADERS, but not vice versa */
+							else if (!strcasecmp(d, "NEWSGROUPS"))
+								nntp_caps.list_newsgroups = TRUE;
+							else if (!strcasecmp(d, "OVERVIEW.FMT")) /* OVER requires OVERVIEW.FMT, but not vice versa */
+								nntp_caps.list_overview_fmt = TRUE;
+							else if (!strcasecmp(d, "MOTD")) /* "private" extension */
+								nntp_caps.list_motd = TRUE;
+							else if (!strcasecmp(d, "SUBSCRIPTIONS")) /* "private" extension, RFC 2980 */
+								nntp_caps.list_subscriptions = TRUE;
+							else if (!strcasecmp(d, "MODERATORS")) /* "private" extension */
+								nntp_caps.list_moderators = TRUE;
+							d = strpbrk(d, " \t");
+						}
+					} else if (!strcasecmp(ptr, "IMPLEMENTATION"))
+						nntp_caps.implementation = my_strdup(ptr + 14);
+					else if (!strcasecmp(ptr, "MODE-READER")) {
+						if (!nntp_caps.reader)
+							nntp_caps.mode_reader = TRUE;
+					} else if (!strcasecmp(ptr, "READER")) {
+						nntp_caps.reader = TRUE;
+						nntp_caps.mode_reader = FALSE;
+					} else if (!strcasecmp(d, "POST"))
+						nntp_caps.post = TRUE;
+					else if (!strcasecmp(ptr, "NEWNEWS"))
+						nntp_caps.newnews = TRUE;
+					else if (!strcasecmp(ptr, "XPAT")) /* extension, RFC 2980 */
+						nntp_caps.xpat = TRUE;
+					else if (!strcasecmp(ptr, "STARTTLS"))
+						nntp_caps.starttls = TRUE;
+					/*
+					 * NOTE: if we saw OVER, LIST OVERVIEW.FMT _must_ be implemented
+					 */
+					else if (!strcasecmp(ptr, &xover_cmds[1])) {
+						nntp_caps.over = TRUE;
+						nntp_caps.list_overview_fmt = TRUE;
+						nntp_caps.over_cmd = &xover_cmds[1];
+						d = ptr + strlen(&xover_cmds[1]);
 						d = strpbrk(d, " \t");
-					}
-				} else if (!strcasecmp(ptr, "AUTHINFO")) {
-					d = ptr + 8;
-					d = strpbrk(d, " \t");
-					while (d != NULL && (d + 1 < (ptr + strlen(ptr)))) {
-						d++;
-						if (!strcasecmp(d, "USER"))
-							nntp_caps.authinfo_user = TRUE;
-						if (!strcasecmp(d, "SASL"))
-							nntp_caps.authinfo_sasl = TRUE;
+						while (d != NULL && (d + 1 < (ptr + strlen(ptr)))) {
+							d++;
+							if (!strcasecmp(d, "MSGID"))
+								nntp_caps.over_msgid = TRUE;
+							d = strpbrk(d, " \t");
+						}
+					} else if (!strcasecmp(ptr, "AUTHINFO")) {
+						d = ptr + 8;
 						d = strpbrk(d, " \t");
+						while (d != NULL && (d + 1 < (ptr + strlen(ptr)))) {
+							d++;
+							if (!strcasecmp(d, "USER"))
+								nntp_caps.authinfo_user = TRUE;
+							if (!strcasecmp(d, "SASL"))
+								nntp_caps.authinfo_sasl = TRUE;
+							d = strpbrk(d, " \t");
+						}
 					}
-				}
 #		if 0
-				/*
-				 * NOTE: if we saw HDR, LIST HEADERS _must_ be implemented
-				 */
-				else if (!strcasecmp(ptr, &xhdr_cmds[1])) {
+					/*
+					 * NOTE: if we saw HDR, LIST HEADERS _must_ be implemented
+					 */
+					else if (!strcasecmp(ptr, &xhdr_cmds[1])) {
 						nntp_caps.hdr_cmd = &xhdr_cmds[1];
 						nntp_caps.hdr = TRUE;
 						nntp_caps.list_headers = TRUE;
-				}
-				else if (!strcasecmp(ptr, "IHAVE"))
+					}
+					else if (!strcasecmp(ptr, "IHAVE"))
 						nntp_caps.ihave = TRUE;
 #		endif /* 0 */
-				/*
-				 * TODO: SASL, STREAMING
-				 */
-			} else
-				nntp_caps.type = NO;
-		}
+					/*
+					 * TODO: SASL, STREAMING
+					 */
+				} else
+					nntp_caps.type = NO;
+			}
+			break;
+
+		case ERR_GOODBYE:
+			ret = i;
+			error_message(buf);
+			break;
+
+		default:
+			break;
 	}
 #		ifdef DEBUG
 	debug_print_nntp_extensions();
 #		endif /* DEBUG */
-	if (!*sec && !nntp_caps.reader) {
+	if ((ret != ERR_GOODBYE) && !*sec && !nntp_caps.reader) {
 		if (nntp_caps.type == CAPABILITIES && !nntp_caps.mode_reader)
 			return -1; /* no mode-switching and no reader mode, give up */
 		if ((ret = mode_reader(&*sec)) != 0)
@@ -1094,8 +1098,10 @@ check_extensions(
 	}
 
 #	else
-
 	/*
+	 * TODO: the following code can go away in tin 2.0 as it's
+	 *       obsolete by RFC 3977
+	 *
 	 * "LIST EXTENSIONS" is somewhat troublesome as there are a lot
 	 * of broken implementations out there and it is a multiline response
 	 */
@@ -1145,23 +1151,28 @@ check_extensions(
 				/*
 				 * as the server did support LIST EXTENSIONS it's likely that it
 				 * also can do LIST MOTD (we don't bother to parse the LIST
-				 * EXTENSIONS output for MOTD as it never was standartizised;
+				 * EXTENSIONS output for MOTD as it never was standardized;
 				 * draft-ietf-nntpext-base-24.txt only described OVER, HDR and
 				 * LISTGROUP).
 				 */
 				nntp_caps.list_motd = TRUE;
 				break;
 
+			case ERR_GOODBYE:
+				ret = i;
+				error_message(buf);
+				break;
+
 			default:
 				break;
 		}
 #		ifdef DEBUG
 		debug_print_nntp_extensions();
 #		endif /* DEBUG */
-		if (!*sec)
+		if ((ret != ERR_GOODBYE) && !*sec)
 			ret = mode_reader(&*sec);
 	}
-#	endif /* 0 */
+#	endif /* 1 */
 	return ret;
 }
 
@@ -1562,8 +1573,11 @@ get_only_respcode(
 	respcode = (int) strtol(ptr, &end, 10);
 	DEBUG_IO((stderr, "get_only_respcode(%d)\n", respcode));
 
-	/* TODO: reconnect on ERR_FAULT? */
-	if ((respcode == ERR_FAULT || respcode == ERR_GOODBYE || respcode == OK_GOODBYE) && last_put[0] != '\0' && strcmp(last_put, "QUIT")) {
+	/*
+	 * we also reconnect on ERR_FAULT if last_put was ARTICLE or LIST or POST
+	 * as inn (2.2.3) sends ERR_FAULT on timeout
+	 */
+	if (((respcode == ERR_FAULT && !strncmp(last_put, "ARTICLE", 7)) || (respcode == ERR_FAULT && !strncmp(last_put, "POST", 4)) || (respcode == ERR_FAULT && !strcmp(last_put, "LIST")) ||  respcode == ERR_GOODBYE || respcode == OK_GOODBYE) && last_put[0] != '\0' && strcmp(last_put, "QUIT")) {
 		/*
 		 * Maybe server timed out.
 		 * If so, retrying will force a reconnect.
@@ -1626,6 +1640,16 @@ get_respcode(
 		strncpy(savebuf, last_put, sizeof(savebuf) - 1);		/* Take copy, as authenticate() will clobber this */
 
 		if (authenticate(nntp_server, userid, FALSE)) {
+			if (curr_group != NULL) {
+				DEBUG_IO((stderr, _("Rejoin current group\n")));
+				snprintf(last_put, sizeof(last_put), "GROUP %s", curr_group->name);
+				put_server(last_put);
+				s_gets(last_put, NNTP_STRLEN, nntp_rd_fp);
+#	ifdef DEBUG
+				debug_nntp("<<<", last_put);
+#	endif /* DEBUG */
+				DEBUG_IO((stderr, _("Read (%s)\n"), last_put));
+			}
 			strcpy(last_put, savebuf);
 
 			put_server(last_put);
