@@ -3,10 +3,10 @@
  *  Module    : options_menu.c
  *  Author    : Michael Bienia <michael@vorlon.ping.de>
  *  Created   : 2004-09-05
- *  Updated   : 2005-01-30
+ *  Updated   : 2006-10-01
  *  Notes     : Split from config.c
  *
- * Copyright (c) 2004-2005 Michael Bienia <michael@vorlon.ping.de>
+ * Copyright (c) 2004-2006 Michael Bienia <michael@vorlon.ping.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -38,15 +38,13 @@
 #ifndef TIN_H
 #	include "tin.h"
 #endif /* !TIN_H */
-#ifndef TINTBL_H
+#ifndef TINCFG_H
 #	include "tincfg.h"
-#endif /* !TINTBL_H */
+#endif /* !TINCFG_H */
 #ifndef TCURSES_H
 #	include "tcurses.h"
 #endif /* !TCURSES_H */
-#ifndef KEYMAP_H
-#	include "keymap.h"
-#endif /* !KEYMAP_H */
+
 
 #define option_lines_per_page (cLINES - INDEX_TOP - 3)
 
@@ -85,10 +83,10 @@ static void unhighlight_option(enum option_enum option);
  */
 int
 option_row(
-	int option)
+	enum option_enum option)
 {
 	int i = 0;
-	int j = first_option_on_screen;
+	enum option_enum j = first_option_on_screen;
 
 	while (j < option) {
 		if (option_is_visible(j))
@@ -139,7 +137,7 @@ set_option_num(
  */
 t_bool
 option_is_visible(
-	int option)
+	enum option_enum option)
 {
 	switch (option) {
 #ifdef HAVE_COLOR
@@ -162,6 +160,9 @@ option_is_visible(
 		case OPT_COL_TEXT:
 		case OPT_COL_TITLE:
 		case OPT_COL_URLS:
+		case OPT_QUOTE_REGEX:
+		case OPT_QUOTE_REGEX2:
+		case OPT_QUOTE_REGEX3:
 			return tinrc.use_color;
 
 		case OPT_COL_MARKSTAR:
@@ -176,6 +177,10 @@ option_is_visible(
 		case OPT_MONO_MARKDASH:
 		case OPT_MONO_MARKSLASH:
 		case OPT_MONO_MARKSTROKE:
+		case OPT_SLASHES_REGEX:
+		case OPT_STARS_REGEX:
+		case OPT_STROKES_REGEX:
+		case OPT_UNDERSCORES_REGEX:
 			return tinrc.word_highlight;
 
 		default:
@@ -211,7 +216,7 @@ fmt_option_prompt(
 	char *dst,
 	size_t len,
 	t_bool editing,
-	int option)
+	enum option_enum option)
 {
 	char *buf;
 	size_t option_width = MAX(35, cCOLS / 2 - 9);
@@ -224,6 +229,7 @@ fmt_option_prompt(
 
 	if (!option_is_title(option)) {
 		int num = get_option_num(option);
+
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
 		if (wbuf != NULL) {
 			wbuf2 = wstrunc(wbuf, option_width);
@@ -323,6 +329,7 @@ print_any_option(
 #endif /* USE_CURSES */
 }
 
+
 static void
 repaint_option(
 	enum option_enum option)
@@ -586,12 +593,12 @@ unhighlight_option(
  */
 void
 refresh_config_page(
-	int act_option)
+	enum option_enum act_option)
 {
-	static int last_option = 0;
+	static enum option_enum last_option = 0;
 	/* t_bool force_redraw = FALSE; */
 
-	if (act_option < 0) {	/* called by signal handler */
+	if (act_option == SIGNAL_HANDLER) {	/* called by signal handler */
 		/* force_redraw = TRUE; */
 		act_option = last_option;
 		set_last_option_on_screen(first_option_on_screen); /* terminal size may have changed */
@@ -689,17 +696,14 @@ option_right(
 /*
  * options menu so that the user can dynamically change parameters
  *
- * TODO: - why do we use ret_code when we never modify it?  what about calling
- *         code which checks the return value?
- *       - when we change something we need to update the related attributes
+ * TODO: - when we change something we need to update the related attributes
  *         as well (see line 2009).
  */
-int
+void
 change_config_file(
 	struct t_group *group)
 {
 	enum option_enum option, old_option;
-	int ret_code = NO_FILTERING;
 	int mime_encoding = MIME_ENCODING_7BIT;
 	t_bool change_option = FALSE;
 	t_function func;
@@ -718,7 +722,7 @@ change_config_file(
 				/* FALLTHROUGH */
 			case CONFIG_NO_SAVE:
 				clear_note_area();
-				return ret_code;
+				return;
 
 			case GLOBAL_LINE_UP:
 				unhighlight_option(option);
@@ -871,6 +875,10 @@ change_config_file(
 				redraw_screen(option);
 				break;
 
+			case GLOBAL_VERSION:
+				info_message(cvers);
+				break;
+
 			default:
 				break;
 		} /* switch (ch) */
@@ -896,21 +904,20 @@ change_config_file(
 						case OPT_KEEP_DEAD_ARTICLES:
 						case OPT_MARK_IGNORE_TAGS:
 						case OPT_MARK_SAVED_READ:
-						case OPT_PGDN_GOTO_NEXT:
 						case OPT_POS_FIRST_UNREAD:
 						case OPT_POST_PROCESS_VIEW:
+#ifndef DISABLE_PRINTING
 						case OPT_PRINT_HEADER:
+#endif /*! DISABLE_PRINTING */
 						case OPT_PROCESS_ONLY_UNREAD:
 						case OPT_PROMPT_FOLLOWUPTO:
 						case OPT_SHOW_ONLY_UNREAD_GROUPS:
 						case OPT_SHOW_SIGNATURES:
 						case OPT_SIGDASHES:
 						case OPT_SIGNATURE_REPOST:
-						case OPT_SPACE_GOTO_NEXT_UNREAD:
 						case OPT_START_EDITOR_OFFSET:
 						case OPT_STRIP_BLANKS:
 						case OPT_STRIP_NEWSRC:
-						case OPT_TAB_GOTO_NEXT_UNREAD:
 						case OPT_TEX2ISO_CONV:
 						case OPT_THREAD_CATCHUP_ON_EXIT:
 #if defined(HAVE_ICONV_OPEN_TRANSLIT) && defined(CHARSET_CONVERSION)
@@ -1059,6 +1066,7 @@ change_config_file(
 						case OPT_COL_MARKSTROKE:
 						case OPT_COL_URLS:
 #endif /* HAVE_COLOR */
+						case OPT_GOTO_NEXT_UNREAD:
 						case OPT_HIDE_UUE:
 						case OPT_INTERACTIVE_MAILER:
 						case OPT_WORD_H_DISPLAY_MARKS:
@@ -1096,6 +1104,8 @@ change_config_file(
 										grpmenu.curr = n;
 								}
 							}
+							set_last_option_on_screen(first_option_on_screen);
+							redraw_screen(option);
 							clear_message();
 							break;
 
@@ -1377,6 +1387,24 @@ change_config_file(
 							compile_regex(tinrc.strip_was_regex, &strip_was_regex, 0);
 							break;
 
+						case OPT_VERBATIM_BEGIN_REGEX:
+							prompt_option_string(option);
+							FreeIfNeeded(verbatim_begin_regex.re);
+							FreeIfNeeded(verbatim_begin_regex.extra);
+							if (!strlen(tinrc.verbatim_begin_regex))
+								STRCPY(tinrc.verbatim_begin_regex, DEFAULT_VERBATIM_BEGIN_REGEX);
+							compile_regex(tinrc.verbatim_begin_regex, &verbatim_begin_regex, PCRE_ANCHORED);
+							break;
+
+						case OPT_VERBATIM_END_REGEX:
+							prompt_option_string(option);
+							FreeIfNeeded(verbatim_end_regex.re);
+							FreeIfNeeded(verbatim_end_regex.extra);
+							if (!strlen(tinrc.verbatim_end_regex))
+								STRCPY(tinrc.verbatim_end_regex, DEFAULT_VERBATIM_END_REGEX);
+							compile_regex(tinrc.verbatim_end_regex, &verbatim_end_regex, PCRE_ANCHORED);
+							break;
+
 						case OPT_DATE_FORMAT:
 							prompt_option_string(option);
 							if (!strlen(tinrc.date_format)) {
@@ -1436,6 +1464,12 @@ change_config_file(
 							redraw_screen(option);
 							break;
 
+						case OPT_THREAD_PERC:
+							prompt_option_num(option);
+							if (tinrc.thread_perc < 0 || tinrc.thread_perc > 100)
+								tinrc.thread_perc = THREAD_PERC_DEFAULT;
+							break;
+
 						case OPT_WRAP_COLUMN:
 							prompt_option_num(option);
 							/* recook if in an article is open */
@@ -1480,5 +1514,5 @@ change_config_file(
 		} /* if (change_option) */
 	} /* forever */
 	/* NOTREACHED */
-	return ret_code;
+	return;
 }
