@@ -3,10 +3,10 @@
  *  Module    : page.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2005-03-14
+ *  Updated   : 2006-10-01
  *  Notes     :
  *
- * Copyright (c) 1991-2005 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2006 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,12 +41,7 @@
 #ifndef TCURSES_H
 #	include "tcurses.h"
 #endif /* !TCURSES_H */
-#ifndef KEYMAP_H
-#	include "keymap.h"
-#endif /* !KEYMAP_H */
-#ifndef RFC2046_H
-#	include "rfc2046.h"
-#endif /* !RFC2046_H */
+
 
 #if defined(HAVE_IDNA_H) && !defined(_IDNA_H)
 #	include <idna.h>
@@ -305,7 +300,6 @@ show_page(
 	char buf[LEN];
 	char key[MAXKEYLEN];
 	int i, n = 0;
-	int filter_state = NO_FILTERING;
 	int old_sort_art_type = tinrc.sort_article_type;
 	int art_type = GROUP_TYPE_NEWS;
 	t_bool mouse_click_on = TRUE;
@@ -395,8 +389,7 @@ show_page(
 
 			case GLOBAL_PAGE_DOWN:		/* page down or next response */
 			case PAGE_NEXT_UNREAD:
-			case PAGE_PAGE_DOWN3:
-				if (!((func == PAGE_NEXT_UNREAD) && tinrc.tab_goto_next_unread) && deactivate_next_ctrl_l())
+				if (!((func == PAGE_NEXT_UNREAD) && (tinrc.goto_next_unread & GOTO_NEXT_UNREAD_TAB)) && deactivate_next_ctrl_l())
 					draw_page(group->name, 0);
 				else {
 					if (curr_line + ARTLINES >= artlines) {	/* End is already on screen */
@@ -405,12 +398,7 @@ show_page(
 								goto page_goto_next_unread;
 
 							case GLOBAL_PAGE_DOWN:
-								if (tinrc.pgdn_goto_next)
-									goto page_goto_next_unread;
-								break;
-
-							case PAGE_PAGE_DOWN3:			/* <SPACE> */
-								if (tinrc.space_goto_next_unread)
+								if (tinrc.goto_next_unread & GOTO_NEXT_UNREAD_PGDN)
 									goto page_goto_next_unread;
 								break;
 
@@ -419,7 +407,7 @@ show_page(
 						}
 						info_message(_(txt_end_of_art));
 					} else {
-						if ((func == PAGE_NEXT_UNREAD) && tinrc.tab_goto_next_unread)
+						if ((func == PAGE_NEXT_UNREAD) && (tinrc.goto_next_unread & GOTO_NEXT_UNREAD_TAB))
 							goto page_goto_next_unread;
 
 						curr_line += (tinrc.scroll_lines == -2) ? ARTLINES / 2 : ARTLINES;
@@ -686,7 +674,7 @@ page_goto_next_unread:
 
 			case GLOBAL_QUICK_FILTER_SELECT:	/* quickly auto-select article */
 			case GLOBAL_QUICK_FILTER_KILL:		/* quickly kill article */
-				if ((filtered_articles = quick_filter((func == GLOBAL_QUICK_FILTER_KILL) ? FILTER_KILL : FILTER_SELECT, group, &arts[this_resp])))
+				if ((filtered_articles = quick_filter(func, group, &arts[this_resp])))
 					goto return_to_index;
 
 				draw_page(group->name, 0);
@@ -695,7 +683,7 @@ page_goto_next_unread:
 			case GLOBAL_MENU_FILTER_SELECT:		/* auto-select article menu */
 			case GLOBAL_MENU_FILTER_KILL:			/* kill article menu */
 				XFACE_CLEAR();
-				if (filter_menu((func == GLOBAL_MENU_FILTER_KILL) ? FILTER_KILL : FILTER_SELECT, group, &arts[this_resp])) {
+				if (filter_menu(func, group, &arts[this_resp])) {
 					if ((filtered_articles = filter_articles(group)))
 						goto return_to_index;
 				}
@@ -734,23 +722,27 @@ page_goto_next_unread:
 				}
 				break;
 
-			case PAGE_CATCHUP:			/* catchup - mark read, goto next */
-			case PAGE_CATCHUP_NEXT_UNREAD:	/* goto next unread */
-				snprintf(buf, sizeof(buf), _(txt_mark_thread_read), (func == PAGE_CATCHUP_NEXT_UNREAD) ? _(txt_enter_next_thread) : "");
+			case CATCHUP:			/* catchup - mark read, goto next */
+			case CATCHUP_NEXT_UNREAD:	/* goto next unread */
+				/*
+				 * TODO: if (group->attribute->thread_arts == THREAD_NONE)
+				 *       	snprintf(buf, sizeof(buf), _("Mark article as read%s?"), (func == CATCHUP_NEXT_UNREAD) ? _(" and enter next unread article") : "");
+				 *       else
+				 */
+				snprintf(buf, sizeof(buf), _(txt_mark_thread_read), (func == CATCHUP_NEXT_UNREAD) ? _(txt_enter_next_thread) : "");
 				if ((!TINRC_CONFIRM_ACTION) || prompt_yn(buf, TRUE) == 1) {
 					thd_mark_read(group, base[which_thread(this_resp)]);
 					XFACE_CLEAR();
-					return (func == PAGE_CATCHUP_NEXT_UNREAD) ? GRP_NEXTUNREAD : GRP_NEXT;
+					return (func == CATCHUP_NEXT_UNREAD) ? GRP_NEXTUNREAD : GRP_NEXT;
 				}
 				break;
 
-			case PAGE_MARK_THREAD_UNREAD:
+			case MARK_THREAD_UNREAD:
 				thd_mark_unread(group, base[which_thread(this_resp)]);
-				/*
-				 * FIXME: replace txt_thread by txt_article_upper
-				 * if THREAD_NONE
-				 */
-				info_message(_(txt_marked_as_unread), _(txt_thread_upper));
+				if (group->attribute->thread_arts != THREAD_NONE)
+					info_message(_(txt_marked_as_unread), _(txt_thread_upper));
+				else
+					info_message(_(txt_marked_as_unread), _(txt_article_upper));
 				break;
 
 			case PAGE_CANCEL:			/* cancel an article */
@@ -798,14 +790,14 @@ page_goto_next_unread:
 			case GLOBAL_QUIT:	/* return to index page */
 return_to_index:
 				XFACE_CLEAR();
-				if (filter_state == NO_FILTERING && tinrc.sort_article_type != old_sort_art_type)
+				if (tinrc.sort_article_type != old_sort_art_type)
 					make_threads(group, TRUE);
 
 				i = which_thread(this_resp);
 				if (threadnum)
 					*threadnum = which_response(this_resp);
 
-				if (filter_state == FILTERING || filtered_articles) {
+				if (filtered_articles) {
 					int old_top = top_art;
 					long old_artnum = arts[this_resp].artnum;
 
@@ -837,8 +829,7 @@ return_to_index:
 
 			case GLOBAL_OPTION_MENU:	/* option menu */
 				XFACE_CLEAR();
-				if (change_config_file(group) == FILTERING)
-					filter_state = FILTERING;
+				change_config_file(group);
 				draw_page(group->name, 0);
 				break;
 
@@ -901,10 +892,13 @@ return_to_index:
 				break;
 
 			case PAGE_GROUP_SELECT:	/* return to group selection page */
+#if 0
+				/* Hasn't been used since tin 1.1 PL4 */
 				if (filter_state == FILTERING) {
 					filter_articles(group);
 					make_threads(group, FALSE);
 				}
+#endif /* 0 */
 				XFACE_CLEAR();
 				return GRP_RETSELECT;
 
@@ -936,7 +930,7 @@ return_to_index:
 				XFACE_SHOW();
 				break;
 
-			case PAGE_MARK_ARTICLE_UNREAD:	/* mark article as unread(to return) */
+			case MARK_ARTICLE_UNREAD:	/* mark article as unread(to return) */
 				art_mark(group, &arts[this_resp], ART_WILL_RETURN);
 				info_message(_(txt_marked_as_unread), _(txt_article_upper));
 				break;
@@ -1028,7 +1022,7 @@ print_message_page(
 		/*
 		 * rotN encoding on body and sig data only
 		 */
-		if ((rotate != 0) && (curr->flags & (C_BODY | C_SIG))) {
+		if ((rotate != 0) && ((curr->flags & (C_BODY | C_SIG)) || show_all_headers)) {
 			for (p = line; *p; p++) {
 				if (*p >= 'A' && *p <= 'Z')
 					*p = (*p - 'A' + rotate) % 26 + 'A';
@@ -1659,7 +1653,7 @@ draw_page_header(
 	cur_pos += strlen(tmp);
 	free(tmp);
 
-	if (note_h->org && cCOLS - cur_pos - 1 >= strlen(_(txt_at_s)) - 2 + 3) {
+	if (note_h->org && cCOLS - cur_pos - 1 >= (int) strlen(_(txt_at_s)) - 2 + 3) {
 		/* we have enough space to print at least " at ..." */
 		snprintf(buf, line_len, _(txt_at_s), note_h->org);
 
@@ -1694,18 +1688,19 @@ load_article(
 	struct t_group *group)
 {
 #ifdef DEBUG
-	fprintf(stderr, "load_art %s(new=%d, curr=%d)\n", (new_respnum == this_resp) ? "ALREADY OPEN!" : "", new_respnum, this_resp);
+	if (debug == 2)
+		fprintf(stderr, "load_art %s(new=%d, curr=%d)\n", (new_respnum == this_resp) ? "ALREADY OPEN!" : "", new_respnum, this_resp);
 #endif /* DEBUG */
 
 	if (new_respnum != this_resp) {
-		char *progress_mesg;
+		char *progress_mesg = my_strdup(_(txt_reading_article));
 		int ret;
 
 		art_close(&pgart);			/* close previously opened art in pager */
 
-		progress_mesg = my_strdup(_(txt_reading_article));
 		ret = art_open(TRUE, &arts[new_respnum], group, &pgart, TRUE, progress_mesg);
 		free(progress_mesg);
+
 		switch (ret) {
 			case ART_UNAVAILABLE:
 				art_mark(group, &arts[new_respnum], ART_READ);
