@@ -3,10 +3,10 @@
  *  Module    : rfc2046.c
  *  Author    : Jason Faultless <jason@altarstone.com>
  *  Created   : 2000-02-18
- *  Updated   : 2004-07-07
+ *  Updated   : 2005-07-02
  *  Notes     : RFC 2046 MIME article parsing
  *
- * Copyright (c) 2000-2005 Jason Faultless <jason@altarstone.com>
+ * Copyright (c) 2000-2007 Jason Faultless <jason@altarstone.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -38,9 +38,6 @@
 #ifndef TIN_H
 #	include "tin.h"
 #endif /* !TIN_H */
-#ifndef RFC2046_H
-#	include "rfc2046.h"
-#endif /* !RFC2046_H */
 
 
 /*
@@ -361,6 +358,13 @@ parse_content_type(
 
 	/* Look up major type */
 
+	/*
+	 * TODO: remove/ignore comments in the CT-header, currently
+	 *       we do not recognize
+	 *          Content-Type: (foo) text/plain; charset=us-ascii
+	 *       as "text/plain"
+	 */
+
 	/*
 	 * Unrecognised type, treat according to RFC
 	 */
@@ -1001,6 +1005,7 @@ dump_uue(
 	}
 }
 
+
 static void
 dump_art(
 	t_openartinfo *art)
