@@ -3,7 +3,7 @@
  *  Module    : save.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2005-07-02
+ *  Updated   : 2006-09-02
  *  Notes     :
  *
  * Copyright (c) 1991-2006 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
@@ -59,6 +59,7 @@ static FILE *open_save_filename(const char *path, t_bool mbox);
 static int match_content_type(t_part *part, char *type);
 static t_bool check_save_mime_type(t_part *part, const char *mime_types);
 static t_bool decode_save_one(t_part *part, FILE *rawfp, t_bool postproc);
+static t_bool expand_save_filename(char *outpath, const char *path);
 static void generate_filename(char *buf, int buflen, const char *suffix);
 static void post_process_uud(void);
 static void post_process_sh(void);
@@ -126,7 +127,7 @@ check_start_save_any_news(
 		case SAVE_ANY_NEWS:
 			joinpath(logfile, rcdir, "log");
 
-			if (no_write || (fp_log = fopen(logfile, "w" FOPEN_OPTS)) == NULL) {
+			if (no_write || (fp_log = fopen(logfile, "w")) == NULL) {
 				perror_message(_(txt_cannot_open), logfile);
 				fp_log = stdout;
 				verbose = FALSE;
@@ -220,7 +221,7 @@ check_start_save_any_news(
 						joinpath(savefile, path, buf);
 					}
 
-					if ((savefp = fopen(savefile, "w" FOPEN_OPTS)) == NULL) {
+					if ((savefp = fopen(savefile, "w")) == NULL) {
 						fprintf(fp_log, _(txt_cannot_open), savefile);
 						if (verbose)
 							perror_message(_(txt_cannot_open), savefile);
@@ -479,11 +480,7 @@ save_and_process_art(
 		 * This is backward-contemptibility with older versions of tin
 		 */
 		if (!is_mailbox && max > 1) {
-#ifdef VMS
-			const char suffixsep = '-';		/* Suffix seperator for .001 type extensions */
-#else
 			const char suffixsep = '.';
-#endif /* VMS */
 
 			sprintf(&path[strlen(path)], "%c%03d", suffixsep, num_save + 1);
 		}
@@ -558,7 +555,6 @@ t_bool
 create_path(
 	const char *path)
 {
-#ifndef VMS
 	char buf[PATH_LEN];
 	int i, j, len;
 	struct stat st;
@@ -579,15 +575,6 @@ create_path(
 			}
 		}
 	}
-#else
-	if (my_mkdir(path, (mode_t) (S_IRWXU|S_IRUGO|S_IXUGO)) == -1) {
-		if (errno != EEXIST) {
-			perror_message(_(txt_cannot_create), buf);
-			return FALSE;
-		}
-	}
-#endif /* !VMS */
-
 	return TRUE;
 }
 
@@ -614,26 +601,31 @@ generate_filename(
  * Expand metacharacters and use defaults as needed.
  * Return TRUE if the path is a mailbox, or FALSE otherwise.
  */
-t_bool
+static t_bool
 expand_save_filename(
 	char *outpath,
 	const char *path)
 {
-	int ret = strfpath(path, outpath, PATH_LEN, curr_group);
+	char base_filename[PATH_LEN];
+	char buf[PATH_LEN];
+	char buf_path[PATH_LEN];
+	int ret;
 
 	/*
-	 * If no path exists or the above failed in some way, use sensible defaults
-	 * Put the generic path into 'outpath'
+	 * Make sure that externally supplied filename is a filename only and fits
+	 * into buffer
 	 */
-	if ((ret == 0) || !(strrchr(outpath, DIRSEP))) {
-		char buf[PATH_LEN];
+	STRCPY(buf_path, path); base_name(buf_path, base_filename);
 
-		if (!strfpath(curr_group->attribute->savedir, buf, sizeof(buf), curr_group))
-			joinpath(buf, homedir, DEFAULT_SAVEDIR);
-		joinpath(outpath, buf, path);
-		return FALSE;
-	} else
-		return (ret == 1);
+	/* Build default path to save to */
+	if (!(ret = strfpath(curr_group->attribute->savedir, buf, sizeof(buf), curr_group)))
+		joinpath(buf, homedir, DEFAULT_SAVEDIR);
+
+	/* Join path and filename */
+	/* TODO: make sure full path fits into outpath! */
+	joinpath(outpath, buf, base_filename);
+
+	return (ret == 1);	/* should now always evaluate to FALSE */
 }
 
 
@@ -1073,12 +1065,7 @@ post_process_sh(
 	 * Grab the dirname portion
 	 */
 	my_strncpy(file_out_dir, save[0].path, save[0].file - save[0].path);
-
-#ifdef VMS
-	snprintf(file_out, sizeof(file_out), "%ssh.%05d", file_out_dir, (int) process_id);
-#else
 	snprintf(file_out, sizeof(file_out), "%ssh%05d", file_out_dir, (int) process_id);
-#endif /* VMS */
 
 	for (i = 0; i < num_save; i++) {
 		if ((fp_in = fopen(save[i].path, "r")) == NULL)
@@ -1089,7 +1076,7 @@ post_process_sh(
 		while (fgets(buf, (int) sizeof(buf), fp_in) != NULL) {
 			/* find #!/bin/sh style patterns */
 			if ((fp_out == NULL) && pcre_exec(shar_regex.re, shar_regex.extra, buf, strlen(buf), 0, 0, NULL, 0) >= 0)
-				fp_out = fopen(file_out, "w" FOPEN_OPTS);
+				fp_out = fopen(file_out, "w");
 
 			/* write to temp file */
 			if (fp_out != NULL)
