@@ -3,10 +3,10 @@
  *  Module    : search.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2005-03-07
+ *  Updated   : 2005-07-02
  *  Notes     :
  *
- * Copyright (c) 1991-2005 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2007 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -38,9 +38,7 @@
 #ifndef TIN_H
 #	include "tin.h"
 #endif /* !TIN_H */
-#ifndef KEYMAP_H
-#	include "keymap.h"
-#endif /* !KEYMAP_H */
+
 
 /*
  * local prototypes
@@ -135,17 +133,16 @@ get_search_pattern(
 /*
  * called by config.c
  */
-int
+enum option_enum
 search_config(
 	t_bool forward,
 	t_bool repeat,
-	int current,
-	int last)
+	enum option_enum current,
+	enum option_enum last)
 {
 	char *pattern, *buf;
-	int n;
-	int incr;
-	int result = current;
+	enum option_enum n = current;
+	enum option_enum result = current;
 
 	if (!(pattern = get_search_pattern(&forward, repeat, _(txt_search_forwards), _(txt_search_backwards), tinrc.default_search_config, HIST_CONFIG_SEARCH)))
 		return result;
@@ -153,16 +150,14 @@ search_config(
 	if (tinrc.wildcard && !(compile_regex(pattern, &search_regex, PCRE_CASELESS)))
 		return result;
 
-	incr = forward ? 1 : -1;
-
-	current += incr;
-	n = current;
 	do {
-		if (n < 0)
+		if (n == 0 && !forward)
 			n = last;
 		else {
-			if (n > last)
+			if (n == last && forward)
 				n = 0;
+			else
+				n += forward ? 1 : -1;
 		}
 		/* search only visible options */
 		if (option_is_visible(n)) {
@@ -180,7 +175,6 @@ search_config(
 			}
 			free(buf);
 		}
-		n += incr;
 	} while (n != current);
 
 	clear_message();
@@ -203,8 +197,8 @@ search_active(
 	t_bool repeat)
 {
 	char *buf;
+	char *ptr;
 	char buf2[LEN];
-	char *ptr = buf2;
 	int i;
 
 	if (!selmenu.max) {
@@ -390,9 +384,9 @@ subject_search(
 	char *buf;
 
 #ifdef HAVE_UNICODE_NORMALIZATION
-	if (IS_LOCAL_CHARSET("UTF-8")) {
+	if (IS_LOCAL_CHARSET("UTF-8"))
 		buf = normalize(arts[i].subject);
-	} else
+	else
 #endif /* HAVE_UNICODE_NORMALIZATION */
 		buf = my_strdup(arts[i].subject);
 
