@@ -3,10 +3,10 @@
  *  Module    : select.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2005-03-14
+ *  Updated   : 2006-10-01
  *  Notes     :
  *
- * Copyright (c) 1991-2005 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2007 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,9 +41,7 @@
 #ifndef TCURSES_H
 #	include "tcurses.h"
 #endif /* !TCURSES_H */
-#ifndef KEYMAP_H
-#	include "keymap.h"
-#endif /* !KEYMAP_H */
+
 
 /*
  * Local prototypes
@@ -244,10 +242,10 @@ selection_page(
 				}
 				break;
 
-			case SELECT_CATCHUP:			/* catchup - mark all articles as read */
-			case SELECT_CATCHUP_NEXT_UNREAD:	/* and goto next unread group */
+			case CATCHUP:			/* catchup - mark all articles as read */
+			case CATCHUP_NEXT_UNREAD:	/* and goto next unread group */
 				if (selmenu.max)
-					catchup_group(&CURR_GROUP, (func == SELECT_CATCHUP_NEXT_UNREAD));
+					catchup_group(&CURR_GROUP, (func == CATCHUP_NEXT_UNREAD));
 				else
 					info_message(_(txt_no_groups));
 				break;
@@ -344,7 +342,7 @@ selection_page(
 				break;
 
 			case GLOBAL_OPTION_MENU:
-				(void) change_config_file(NULL);
+				change_config_file(NULL);
 				read_attributes_files();
 				show_selection_page();
 				break;
@@ -814,8 +812,8 @@ int
 choose_new_group(
 	void)
 {
-	int idx;
 	char *prompt;
+	int idx;
 
 	prompt = fmt_string(_(txt_newsgroup), tinrc.default_goto_group);
 
