@@ -3,10 +3,10 @@
  *  Module    : string.c
  *  Author    : Urs Janssen <urs@tin.org>
  *  Created   : 1997-01-20
- *  Updated   : 2005-03-08
+ *  Updated   : 2005-11-04
  *  Notes     :
  *
- * Copyright (c) 1997-2005 Urs Janssen <urs@tin.org>
+ * Copyright (c) 1997-2007 Urs Janssen <urs@tin.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -73,19 +73,26 @@
 
 /*
  * special ltoa()
- * converts value into a string with a len of digits
- * last char may be one of the following
- * Kilo, Mega, Giga, Terra
+ * converts value into a string with a maxlen of digits (usualy should be
+ * >=4), last char may be one of the following:
+ * 'K'ilo, 'M'ega, 'G'iga, 'T'erra, 'P'eta, 'E'xa, 'Z'etta, 'Y'otta,
+ * 'X'ona, 'W'eka, 'V'unda, 'U'da (these last 4 are no official SI-prefixes)
+ * or 'e' if an error occurs
  */
 char *
 tin_ltoa(
 	long value,
 	int digits)
 {
-	static char buffer[256];
-	static const char power[] = " KMGT";
+	static char buffer[64];
+	static const char power[] = { ' ', 'K', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y', 'X', 'W', 'V', 'U', '\0' };
 	int len;
-	int i = 0;
+	size_t i = 0;
+
+	if (digits <= 0) {
+		buffer[0] = 'e';
+		return buffer;
+	}
 
 	snprintf(buffer, sizeof(buffer), "%ld", value);
 	len = (int) strlen(buffer);
@@ -95,11 +102,21 @@ tin_ltoa(
 		i++;
 	}
 
+	if (i >= strlen(power)) {	/* buffer is to small */
+		buffer[(digits & 0x7f) - 1] = 'e';
+		buffer[(digits & 0x7f)] = '\0';
+		return buffer;
+	}
+
 	if (i) {
 		while (len < (digits - 1))
 			buffer[len++] = ' ';
 
-		buffer[digits - 1] = power[i];
+		if (digits > len)
+			buffer[digits - 1] = power[i];
+		else /* overflow */
+			buffer[digits - 1] = 'e';
+
 		buffer[digits] = '\0';
 	} else
 		snprintf(buffer, sizeof(buffer), "%*ld", digits, value);
@@ -448,6 +465,28 @@ strncasecmp(
 }
 #endif /* !HAVE_STRNCASECMP */
 
+#ifndef HAVE_STRSEP
+/*
+ * strsep() is not mandatory in ANSI-C
+ */
+char *strsep(
+	char **stringp,
+	const char *delim)
+{
+	char *s = *stringp;
+	char *p;
+
+	if (!s)
+		return NULL;
+
+	if ((p = strpbrk(s, delim)) != NULL)
+		*p++ = '\0';
+
+	*stringp = p;
+	return s;
+}
+#endif /* !HAVE_STRSEP */
+
 
 /*
  * str_trim - leading and trailing whitespace
@@ -542,11 +581,11 @@ sh_format(
 	const char *fmt,
 	...)
 {
-	int result = 0;
 	char *src;
 	char temp[20];
-	va_list ap;
+	int result = 0;
 	int quote = 0;
+	va_list ap;
 
 	va_start(ap, fmt);
 
@@ -702,8 +741,8 @@ char *
 wchar_t2char(
 	const wchar_t *wstr)
 {
-	size_t len;
 	char *str;
+	size_t len;
 
 	len = wcstombs(NULL, wstr, 0);
 	if (len == (size_t) (-1))
@@ -799,6 +838,7 @@ strunc(
 	return tmp;
 }
 
+
 /*
  * if you use UTF-8 as local charset and want to use
  * U+2026 (HORIZONTAL_ELLIPSIS) instead of "..." uncomment
@@ -897,8 +937,8 @@ static char *
 UChar2char(
 	const UChar *ustr)
 {
-	int32_t needed;
 	char *str;
+	int32_t needed;
 	UErrorCode status = U_ZERO_ERROR;
 
 	u_strToUTF8(NULL, 0, &needed, ustr, -1, &status);
@@ -1047,8 +1087,8 @@ render_bidi(
 	const char *str,
 	t_bool *is_rtl)
 {
-	int32_t ustr_len;
 	char *tmp;
+	int32_t ustr_len;
 	UBiDi *bidi_data;
 	UChar *ustr, *ustr_reordered;
 	UErrorCode status = U_ZERO_ERROR;
