@@ -3,10 +3,10 @@
  *  Module    : thread.c
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2005-03-14
+ *  Updated   : 2006-09-16
  *  Notes     :
  *
- * Copyright (c) 1991-2005 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2007 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,11 +41,9 @@
 #ifndef TCURSES_H
 #	include "tcurses.h"
 #endif /* !TCURSES_H */
-#ifndef KEYMAP_H
-#	include "keymap.h"
-#endif /* !KEYMAP_H */
 
-#define EXPIRED(a) ((a)->article == ART_UNAVAILABLE || arts[(a)->article].thread == ART_EXPIRED)
+
+#define IS_EXPIRED(a) ((a)->article == ART_UNAVAILABLE || arts[(a)->article].thread == ART_EXPIRED)
 
 int thread_basenote = 0;				/* Index in base[] of basenote */
 static int thread_respnum = 0;			/* Index in arts[] of basenote ie base[thread_basenote] */
@@ -149,6 +147,11 @@ build_tline(
 	 * Start with 2 spaces for ->
 	 * then index number of the message and whitespace (2+4+1 chars)
 	 */
+#if 0 /* usefull? see also group.c:build_sline() */
+	if (!tinrc.draw_arrow)
+		sprintf(buffer, "%s ", tin_ltoa(l + 1, 6));
+	else
+#endif /* 0 */
 	sprintf(buffer, "  %s ", tin_ltoa(l + 1, 4));
 	rest_of_line -= 7;
 
@@ -242,7 +245,7 @@ build_tline(
 		if (gap > 0) {
 			size_t len = strlen(buffer);
 
-			for (ptr = art->refptr->parent; ptr && EXPIRED(ptr); ptr = ptr->parent)
+			for (ptr = art->refptr->parent; ptr && IS_EXPIRED(ptr); ptr = ptr->parent)
 				;
 			if (!(ptr && arts[ptr->article].subject == art->subject)) {
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
@@ -445,7 +448,7 @@ thread_page(
 	 * See if we're on a direct call from the group menu to the pager
 	 */
 	if (page) {
-		if ((ret_code = enter_pager(page->art, page->ignore_unavail, GROUP_LEVEL)) != 0)
+		if ((ret_code =	enter_pager(page->art, page->ignore_unavail, GROUP_LEVEL)) != 0)
 			return ret_code;
 		/* else fall through to stay in thread level */
 	}
@@ -543,7 +546,7 @@ thread_page(
 				 *        is 'troublesome'
 				 */
 				n = find_response(thread_basenote, thdmenu.curr);
-				filter_menu((func == GLOBAL_MENU_FILTER_KILL) ? FILTER_KILL : FILTER_SELECT, group, &arts[n]);
+				filter_menu(func, group, &arts[n]);
 				if (filter_articles(group)) {
 					make_threads(group, FALSE);
 					if ((n = next_unread(n)) == -1) {
@@ -615,8 +618,8 @@ thread_page(
 				break;
 
 			case SPECIAL_CATCHUP_LEFT:				/* come here when exiting thread via <- */
-			case THREAD_CATCHUP:				/* catchup thread, move to next one */
-			case THREAD_CATCHUP_NEXT_UNREAD:	/* -> next with unread arts */
+			case CATCHUP:				/* catchup thread, move to next one */
+			case CATCHUP_NEXT_UNREAD:	/* -> next with unread arts */
 				ret_code = thread_catchup(func);
 				break;
 
@@ -732,7 +735,7 @@ thread_page(
 				info_message(cvers);
 				break;
 
-			case THREAD_MARK_ARTICLE_UNREAD:	/* mark article as unread */
+			case MARK_ARTICLE_UNREAD:	/* mark article as unread */
 				n = find_response(thread_basenote, thdmenu.curr);
 				art_mark(group, &arts[n], ART_WILL_RETURN);
 				mark[0] = get_art_mark(&arts[n]);
@@ -741,7 +744,7 @@ thread_page(
 				info_message(_(txt_marked_as_unread), _(txt_article_upper));
 				break;
 
-			case THREAD_MARK_THREAD_UNREAD:		/* mark thread as unread */
+			case MARK_THREAD_UNREAD:		/* mark thread as unread */
 				thd_mark_unread(group, base[thread_basenote]);
 				update_thread_page();
 				info_message(_(txt_marked_as_unread), _(txt_thread_upper));
@@ -792,7 +795,7 @@ thread_page(
 				break;
 
 			default:
-				info_message(_(txt_bad_command), printascii(key, key_to_func(GLOBAL_HELP, thread_keys)));
+				info_message(_(txt_bad_command), printascii(key, func_to_key(GLOBAL_HELP, thread_keys)));
 		}
 	} /* ret_code >= 0 */
 
@@ -807,8 +810,8 @@ static void
 show_thread_page(
 	void)
 {
-	int i, art;
 	char *title;
+	int i, art;
 
 	signal_context = cThread;
 	currmenu = &thdmenu;
@@ -1269,7 +1272,7 @@ static t_bool
 find_unexpired(
 	struct t_msgid *ptr)
 {
-	return ptr && (!EXPIRED(ptr) || find_unexpired(ptr->child) || find_unexpired(ptr->sibling));
+	return ptr && (!IS_EXPIRED(ptr) || find_unexpired(ptr->child) || find_unexpired(ptr->sibling));
 }
 
 
@@ -1281,7 +1284,7 @@ has_sibling(
 		if (find_unexpired(ptr->sibling))
 			return TRUE;
 		ptr = ptr->parent;
-	} while (ptr && EXPIRED(ptr));
+	} while (ptr && IS_EXPIRED(ptr));
 	return FALSE;
 }
 
@@ -1306,7 +1309,7 @@ make_prefix(
 	struct t_msgid *ptr;
 
 	for (ptr = art->parent; ptr; ptr = ptr->parent)
-		depth += (!EXPIRED(ptr) ? 1 : 0);
+		depth += (!IS_EXPIRED(ptr) ? 1 : 0);
 
 	if ((depth == 0) || (maxlen < 1)) {
 		prefix[0] = '\0';
@@ -1333,7 +1336,7 @@ make_prefix(
 	buf[--prefix_ptr] = (has_sibling(art) ? '+' : '`');
 
 	for (ptr = art->parent; prefix_ptr > 1; ptr = ptr->parent) {
-		if (EXPIRED(ptr))
+		if (IS_EXPIRED(ptr))
 			continue;
 		buf[--prefix_ptr] = ' ';
 		buf[--prefix_ptr] = (has_sibling(ptr) ? '|' : ' ');
@@ -1372,18 +1375,23 @@ thread_catchup(
 	}
 
 	if (i != -1) {				/* still unread arts in this thread */
-		snprintf(buf, sizeof(buf), _(txt_mark_thread_read), (func == THREAD_CATCHUP_NEXT_UNREAD) ? _(txt_enter_next_thread) : "");
+		/*
+		 * TODO: if (group->attribute->thread_arts == THREAD_NONE)
+		 *          snprintf(buf, sizeof(buf), _("Mark article as read%s?"), (func == CATCHUP_NEXT_UNREAD) ? _(" and enter next unread article") : "");
+		 *       else
+		 */
+		snprintf(buf, sizeof(buf), _(txt_mark_thread_read), (func == CATCHUP_NEXT_UNREAD) ? _(txt_enter_next_thread) : "");
 		if ((!TINRC_CONFIRM_ACTION) || (pyn = prompt_yn(buf, TRUE)) == 1)
 			thd_mark_read(curr_group, base[thread_basenote]);
 	}
 
 	switch (func) {
-		case THREAD_CATCHUP:				/* 'c' */
+		case CATCHUP:				/* 'c' */
 			if (pyn == 1)
 				return GRP_NEXT;
 			break;
 
-		case THREAD_CATCHUP_NEXT_UNREAD:	/* 'C' */
+		case CATCHUP_NEXT_UNREAD:	/* 'C' */
 			if (pyn == 1)
 				return GRP_NEXTUNREAD;
 			break;
@@ -1459,6 +1467,7 @@ again:
 
 		case GRP_GOTOTHREAD:		/* 'l' from pager */
 			show_thread_page();
+			move_to_item(which_response(this_resp));
 			return 0;
 
 		default:					/* >=0 normal exit, new basenote */
@@ -1520,7 +1529,7 @@ mark_art_read(
 	struct t_group *group)
 {
 	char keytagged[MAXKEYLEN], keycurrent[MAXKEYLEN], keyquit[MAXKEYLEN];
-	int n = -1, cnt = 0;
+	int n, cnt = 0;
 	int tmp_num_of_tagged_arts = num_of_tagged_arts;
 	t_function func = MARK_READ_CURRENT;
 
