@@ -3,10 +3,10 @@
  *  Module    : version.c
  *  Author    : U. Janssen
  *  Created   : 2003-05-11
- *  Updated   : 2005-01-30
+ *  Updated   : 2005-07-02
  *  Notes     :
  *
- * Copyright (c) 2003-2005 Urs Janssen <urs@tin.org>
+ * Copyright (c) 2003-2007 Urs Janssen <urs@tin.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,9 +41,7 @@
 #ifndef VERSION_H
 #	include "version.h"
 #endif /* !VERSION_H */
-#ifndef KEYMAP_H
-#	include "keymap.h"
-#endif /* !KEYMAP_H */
+
 
 /*
  * line     is the entire line we should check
