@@ -3,10 +3,10 @@
  *  Module    : xref.c
  *  Author    : I. Lea & H. Brugge
  *  Created   : 1993-07-01
- *  Updated   : 2005-02-11
+ *  Updated   : 2005-05-04
  *  Notes     :
  *
- * Copyright (c) 1993-2005 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1993-2006 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -62,7 +62,7 @@ open_overview_fmt_fp(
 
 #ifdef NNTP_ABLE
 	if (read_news_via_nntp && !read_saved_news) {
-		if (!xover_cmd)
+		if (!nntp_caps.over_cmd)
 			return (FILE *) 0;
 
 		snprintf(line, sizeof(line), "LIST %s", OVERVIEW_FMT);
