@@ -4,7 +4,7 @@
 # signs the article and posts it.
 #
 #
-# Copyright (c) 2002-2006 Urs Janssen <urs@tin.org>,
+# Copyright (c) 2002-2007 Urs Janssen <urs@tin.org>,
 #                         Marc Brockschmidt <marc@marcbrockschmidt.de>
 #
 # Redistribution and use in source and binary forms, with or without
@@ -44,7 +44,7 @@
 #       - cleanup, remove duplicated code
 #
 # version Number
-my $version = "1.1.7";
+my $version = "1.1.10";
 
 my %config;
 
@@ -59,6 +59,7 @@ $config{'PathtoPGPPass'}= '';		# pgp2, pgp5 and gpg
 
 $config{'pgp'}		= '/usr/bin/pgp';# path to pgp
 $config{'PGPVersion'}	= '2';		# Use 2 for 2.X, 5 for PGP > 2.X and GPG for GPG
+$config{'digest-algo'}	= 'MD5';	# Digest Algorithm for GPG -- Must be supported by your installation
 
 $config{'Interactive'}	= "yes";	# allow interactive usage
 
@@ -424,9 +425,9 @@ sub getpgpcommand {
 		}
 	} elsif ($PGPVersion =~ m/GPG/io) {
 		if ($config{'PathtoPGPPass'}) {
-			$PGPCommand = $config{'pgp'}." --digest-algo MD5 -a -u \"".$config{'PGPSigner'}."\" -o ".$config{'pgptmpf'}.".txt.asc --no-tty --batch --passphrase-fd 42 42<".$config{'PathtoPGPPass'}." --clearsign ".$config{'pgptmpf'}.".txt";
+			$PGPCommand = $config{'pgp'}." --digest-algo $config{'digest-algo'} -a -u \"".$config{'PGPSigner'}."\" -o ".$config{'pgptmpf'}.".txt.asc --no-tty --batch --passphrase-fd 42 42<".$config{'PathtoPGPPass'}." --clearsign ".$config{'pgptmpf'}.".txt";
 		} elsif ($config{'Interactive'}) {
-			$PGPCommand = $config{'pgp'}." --digest-algo MD5 -a -u \"".$config{'PGPSigner'}."\" -o ".$config{'pgptmpf'}.".txt.asc --no-secmem-warning --no-batch --clearsign ".$config{'pgptmpf'}.".txt";
+			$PGPCommand = $config{'pgp'}." --digest-algo $config{'digest-algo'} -a -u \"".$config{'PGPSigner'}."\" -o ".$config{'pgptmpf'}.".txt.asc --no-secmem-warning --no-batch --clearsign ".$config{'pgptmpf'}.".txt";
 		} else {
 			die "$0: Passphrase is unknown!\n";
 		}
@@ -496,6 +497,7 @@ sub signarticle {
 		}
 	}
 
+	unless (substr($pgpbody,-1,1)=~ /\n/ ) {$pgpbody.="\n"};
 	open(FH, ">" . $config{'pgptmpf'} . ".txt") or die "$0: can't open ".$config{'pgptmpf'}.": $!\n";
 	print FH $pgphead, "\n", $pgpbody;
 	print FH "\n" if ($config{'PGPVersion'} =~ m/GPG/io);	# workaround a pgp/gpg incompatibility - should IMHO be fixed in pgpverify
@@ -562,6 +564,7 @@ sub signarticle {
 		}
 	}
 
+	push @pgphead, ("X-PGP-Hash: " . $config{'digest-algo'} . "\n");
 	push @pgphead, ("X-PGP-Key: " . $config{'PGPSigner'} . "\n"), $tmppgpheader;
 	undef $tmppgpheader;
 
